/////////////////////////////////////////////////////////////// 
//Copyright (c) 2003 Northrop Grumman Corporation
// All data contained herein is proprietary information of
// Northrop Grumman Corporation and is subject to
// the above Copyright notice. 
///////////////////////////////////////////////////////////////
using System;
using System.Collections;
using System.Data;
using System.Windows.Forms;
using System.ComponentModel;
using System.Drawing;
using System.Text;

using NorthGrum.CommandPoint.AdminBusinessObjects;
using NorthGrum.CommandPoint.Common.CADLog;
using NorthGrum.CommandPoint.ResourceLibrary;
using NorthGrum.CommandPoint.UIControls.BaseControls;
using NorthGrum.CommandPoint.UIControls.GridControls;
using NorthGrum.CommandPoint.UIManager;
using NorthGrum.CommandPoint.Validators.GenericValidators;
using NorthGrum.CommandPoint.Validators.FormValidators;
using NorthGrum.CommandPoint.DataServices.BusinessDataObjects;
using NorthGrum.CommandPoint.DataServices.Factory;
using NorthGrum.CommandPoint.DataServices.Factory.Interfaces ;
using NorthGrum.CommandPoint.Common;
using Syncfusion.Windows.Forms.Grid;

namespace NorthGrum.CommandPoint.AdminUI
{
    /// <summary>
    /// UI Form Class that gets loaded for NGP Command.
    /// </summary>
    [Configurable("NGP Definition Form")]
    public sealed class FormNGP : BaseForm
    {
        #region Private Members
        private NGSyncTabPageAdv tabPageHistory;
        private DataRowView selectedRow;
        private GridListControl listControl;
        private GenericGridDisplayInfoCollection gridDisplayInfoCollection = new GenericGridDisplayInfoCollection();
        private System.ComponentModel.IContainer components;
        private NGSyncTabPageAdv tabPageMain;
        private NGSyncAutoCompleteComboBox ddlAgency;
        private NGTextBox txtAgenciesInCongrpid;
        private NGTextBox txtCongrpid;
        private NGLabel lblAgencyGroup;
        private NGLabel lblDataGroup;
        private NGLabel lblAgency;
        private CP_HistoryDisplay cP_HistoryDisplayNGP;
        private string THIS_CLASS = "FormNGP";
        private CommandParser commandLineParameters = null;
        private NGGroupBox grpBoxGrpNotification;
        private NGSyncTabPageAdv tabPageNotification;
        private NGGroupBox grpBoxResults;
        private NGLabel lblNotificationType;
        private NGSyncAutoCompleteComboBox ddlNotificationType;
        private NGLabel lblNotificationGroupId;
        private NGTextBox txtNotificationGrpID;
        private NGSyncTabAdv tabControlNGP;
        private NGSyncfusionGrid grdGrpNotification;
        private NGSyncfusionGrid gdbgResults;
        private CP_FormButtons cP_FormButtonsNGP;
        private CADBaseNGPCollection CadBaseNGPObject = new CADBaseNGPCollection();
        private CADBaseNGP currentCadObject = new CADBaseNGP();
        private NGPushButton btnSave;
        private string[] agenciesInCongrpid = null;
        private NRSNotificationTypeValidator dvNotificationType = new NRSNotificationTypeValidator();
        private NRSNotificationTypeValidator ddcNotificationType = new NRSNotificationTypeValidator();
        private NGGroupBox grpBoxGroupType;
        private NGLabel lblNotfyExceed;
        private NGLabel lblToTime;
        private NGLabel lblFromTime;
        private NGLabel lblSubstituteTime;
        private NGLabel lblService;
        private NGLabel lblNotifId;
        private NGLabel lblSubstituteDefinition;
        private NGSyncAutoCompleteComboBox cbService;
        private NGSyncDateTimePicker dtToDate;
        private NGSyncDateTimePicker dtFromDate;
        private NGTextBox txtNumberNotification;
        private NGTextBox txtNotificationID;
        private NGRadioButton rdDestinationSub;
        private NGRadioButton rdMultipleDestination;
        private System.Windows.Forms.ErrorProvider errorProvider;
        private NGSyncGridBoundColumn colDescription;
        private NGSyncGridBoundColumn colResponseType;
        private NGSyncGridBoundColumn colResponseID;
        private NGSyncGridBoundColumn colNotificationNumber;
        private NGSyncGridBoundColumn colDisplayName;
        private NGSyncGridBoundColumn notificationType;
        private NGSyncGridBoundColumn notificationGroupID;
        private NGSyncGridBoundColumn colResourceType;
        private const int PreferredDropDownRowNum = 10;
        private bool displayInProgress=false;
        private bool agencyChanged=false;
		private NGSyncGridBoundColumn colCongrpid;
		private NGSyncGridBoundColumn colResCongrpID;
        private string agency;

        /// <summary>
        /// Cadbase NGP Object Property
        /// </summary>
        private CADBaseNGP CadBaseObject
        {
            get
            {
                if (CadBaseNGPObject.Count == 0)
                {
                    return null;
                }
                else
                {
                    return (CADBaseNGP) this.gdbgResults.BindingContext[CadBaseNGPObject].Current;
                }
            }
        }
        /// <summary>
        /// Unsaved changes exist in the form.
        /// </summary>
        private bool ChangesToSave
        {
            get
            {
                foreach (CADBase cadBaseObject in this.CadBaseNGPObject)
                {
                    //if the record is not in Query status and is valid for add and is 
                    //not an empty row with just default values
                    if (cadBaseObject.RecordStatus != CADBase.RecordStatusFlags.Query && cadBaseObject.ValidForAdd()
                        && cadBaseObject.RecordStatus != CADBase.RecordStatusFlags.New)
                    {
                        return true;
                    }
                }
                return false;
            }
        }
		
        #endregion

        #region Constructors
        /// <summary>
        /// NGP constructor
        /// </summary>
        public FormNGP() : this(null){}
		
        /// <summary>
        /// NGP Parameter constructor
        /// </summary>
        /// <param name="parameters"></param>
        public FormNGP(CommandParser parameters)
        {
            InitializeComponent();
            gdbgResults.DataBoundGridModel.CellModels.Add("NGGridListCell", new NGGridListCellModel(gdbgResults.DataBoundGridModel.Model));
            grdGrpNotification.DataBoundGridModel.CellModels.Add("NGGridListCell", new NGGridListCellModel(grdGrpNotification.DataBoundGridModel.Model));
            commandLineParameters = parameters;
            this.dtToDate.ShowCheckBox = true;
            this.dtFromDate.ShowCheckBox = true;
        }

        /// <summary>
        /// Clean up any resources being used.
        /// </summary>
        protected override void Dispose( bool disposing )
        {
            if( disposing )
            {
                if(components != null)
                {
                    components.Dispose();
                }
            }
            base.Dispose( disposing );
        }
        #endregion

        #region Windows Generated Code
        /// <summary>
        /// Required method for Designer support - do not modify
        /// the contents of this method with the code editor.
        /// </summary>
        private void InitializeComponent()
        {
			this.components = new System.ComponentModel.Container();
			Syncfusion.Windows.Forms.Grid.GridStyleInfo gridStyleInfo1 = new Syncfusion.Windows.Forms.Grid.GridStyleInfo();
			Syncfusion.Windows.Forms.Grid.GridStyleInfo gridStyleInfo2 = new Syncfusion.Windows.Forms.Grid.GridStyleInfo();
			this.tabControlNGP = new NorthGrum.CommandPoint.UIControls.BaseControls.NGSyncTabAdv();
			this.tabPageMain = new NorthGrum.CommandPoint.UIControls.BaseControls.NGSyncTabPageAdv();
			this.grpBoxGroupType = new NorthGrum.CommandPoint.UIControls.BaseControls.NGGroupBox();
			this.cbService = new NorthGrum.CommandPoint.UIControls.BaseControls.NGSyncAutoCompleteComboBox();
			this.dtToDate = new NorthGrum.CommandPoint.UIControls.BaseControls.NGSyncDateTimePicker();
			this.dtFromDate = new NorthGrum.CommandPoint.UIControls.BaseControls.NGSyncDateTimePicker();
			this.txtNumberNotification = new NorthGrum.CommandPoint.UIControls.BaseControls.NGTextBox();
			this.lblNotfyExceed = new NorthGrum.CommandPoint.UIControls.BaseControls.NGLabel();
			this.lblToTime = new NorthGrum.CommandPoint.UIControls.BaseControls.NGLabel();
			this.lblFromTime = new NorthGrum.CommandPoint.UIControls.BaseControls.NGLabel();
			this.lblSubstituteTime = new NorthGrum.CommandPoint.UIControls.BaseControls.NGLabel();
			this.lblService = new NorthGrum.CommandPoint.UIControls.BaseControls.NGLabel();
			this.txtNotificationID = new NorthGrum.CommandPoint.UIControls.BaseControls.NGTextBox();
			this.lblNotifId = new NorthGrum.CommandPoint.UIControls.BaseControls.NGLabel();
			this.lblSubstituteDefinition = new NorthGrum.CommandPoint.UIControls.BaseControls.NGLabel();
			this.rdDestinationSub = new NorthGrum.CommandPoint.UIControls.BaseControls.NGRadioButton();
			this.rdMultipleDestination = new NorthGrum.CommandPoint.UIControls.BaseControls.NGRadioButton();
			this.grpBoxResults = new NorthGrum.CommandPoint.UIControls.BaseControls.NGGroupBox();
			this.gdbgResults = new NorthGrum.CommandPoint.UIControls.GridControls.NGSyncfusionGrid();
			this.notificationType = new NorthGrum.CommandPoint.UIControls.BaseControls.NGSyncGridBoundColumn(this.components);
			this.notificationGroupID = new NorthGrum.CommandPoint.UIControls.BaseControls.NGSyncGridBoundColumn(this.components);
			this.tabPageNotification = new NorthGrum.CommandPoint.UIControls.BaseControls.NGSyncTabPageAdv();
			this.grpBoxGrpNotification = new NorthGrum.CommandPoint.UIControls.BaseControls.NGGroupBox();
			this.grdGrpNotification = new NorthGrum.CommandPoint.UIControls.GridControls.NGSyncfusionGrid();
			this.colResourceType = new NorthGrum.CommandPoint.UIControls.BaseControls.NGSyncGridBoundColumn(this.components);
			this.colDescription = new NorthGrum.CommandPoint.UIControls.BaseControls.NGSyncGridBoundColumn(this.components);
			this.colResponseType = new NorthGrum.CommandPoint.UIControls.BaseControls.NGSyncGridBoundColumn(this.components);
			this.colResponseID = new NorthGrum.CommandPoint.UIControls.BaseControls.NGSyncGridBoundColumn(this.components);
			this.colNotificationNumber = new NorthGrum.CommandPoint.UIControls.BaseControls.NGSyncGridBoundColumn(this.components);
			this.colDisplayName = new NorthGrum.CommandPoint.UIControls.BaseControls.NGSyncGridBoundColumn(this.components);
			this.tabPageHistory = new NorthGrum.CommandPoint.UIControls.BaseControls.NGSyncTabPageAdv();
			this.cP_HistoryDisplayNGP = new NorthGrum.CommandPoint.UIControls.BaseControls.CP_HistoryDisplay();
			this.ddlAgency = new NorthGrum.CommandPoint.UIControls.BaseControls.NGSyncAutoCompleteComboBox();
			this.txtAgenciesInCongrpid = new NorthGrum.CommandPoint.UIControls.BaseControls.NGTextBox();
			this.txtCongrpid = new NorthGrum.CommandPoint.UIControls.BaseControls.NGTextBox();
			this.lblAgencyGroup = new NorthGrum.CommandPoint.UIControls.BaseControls.NGLabel();
			this.lblDataGroup = new NorthGrum.CommandPoint.UIControls.BaseControls.NGLabel();
			this.lblAgency = new NorthGrum.CommandPoint.UIControls.BaseControls.NGLabel();
			this.lblNotificationType = new NorthGrum.CommandPoint.UIControls.BaseControls.NGLabel();
			this.ddlNotificationType = new NorthGrum.CommandPoint.UIControls.BaseControls.NGSyncAutoCompleteComboBox();
			this.lblNotificationGroupId = new NorthGrum.CommandPoint.UIControls.BaseControls.NGLabel();
			this.txtNotificationGrpID = new NorthGrum.CommandPoint.UIControls.BaseControls.NGTextBox();
			this.cP_FormButtonsNGP = new NorthGrum.CommandPoint.UIControls.BaseControls.CP_FormButtons();
			this.btnSave = new NorthGrum.CommandPoint.UIControls.BaseControls.NGPushButton();
			this.errorProvider = new System.Windows.Forms.ErrorProvider();
			this.colCongrpid = new NGSyncGridBoundColumn();
			this.colResCongrpID = new NGSyncGridBoundColumn();
			((System.ComponentModel.ISupportInitialize)(this.tabControlNGP)).BeginInit();
			this.tabControlNGP.SuspendLayout();
			this.tabPageMain.SuspendLayout();
			this.grpBoxGroupType.SuspendLayout();
			((System.ComponentModel.ISupportInitialize)(this.cbService.AutoCompleteControl)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.dtToDate)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.dtToDate.Calendar)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.dtFromDate)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.dtFromDate.Calendar)).BeginInit();
			this.grpBoxResults.SuspendLayout();
			((System.ComponentModel.ISupportInitialize)(this.gdbgResults)).BeginInit();
			this.tabPageNotification.SuspendLayout();
			this.grpBoxGrpNotification.SuspendLayout();
			((System.ComponentModel.ISupportInitialize)(this.grdGrpNotification)).BeginInit();
			this.tabPageHistory.SuspendLayout();
			((System.ComponentModel.ISupportInitialize)(this.ddlAgency.AutoCompleteControl)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.ddlNotificationType.AutoCompleteControl)).BeginInit();
			this.SuspendLayout();
			// 
			// _commandLineControl
			// 
			this._commandLineControl.Dock = System.Windows.Forms.DockStyle.Top;
			this._commandLineControl.Name = "_commandLineControl";
			this._commandLineControl.Size = new System.Drawing.Size(860, 64);
			// 
			// tabControlNGP
			// 
			this.tabControlNGP.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom) 
				| System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right)));
			this.tabControlNGP.Controls.Add(this.tabPageMain);
			this.tabControlNGP.Controls.Add(this.tabPageNotification);
			this.tabControlNGP.Controls.Add(this.tabPageHistory);
			this.tabControlNGP.Font = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.tabControlNGP.Location = new System.Drawing.Point(12, 136);
			this.tabControlNGP.Name = "tabControlNGP";
			this.tabControlNGP.Size = new System.Drawing.Size(844, 390);
			this.tabControlNGP.TabIndex = 11;
			this.tabControlNGP.ThemesEnabled = true;
			this.tabControlNGP.SelectedIndexChanged += new System.EventHandler(this.tabControlNGP_SelectedIndexChanged);
			// 
			// tabPageMain
			// 
			this.tabPageMain.Controls.Add(this.grpBoxGroupType);
			this.tabPageMain.Controls.Add(this.grpBoxResults);
			this.tabPageMain.Font = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.tabPageMain.IsTransparent = false;
			this.tabPageMain.Location = new System.Drawing.Point(1, 30);
			this.tabPageMain.Name = "tabPageMain";
			this.tabPageMain.Size = new System.Drawing.Size(841, 358);
			this.tabPageMain.TabIndex = 0;
			this.tabPageMain.Text = "&Main";
			this.tabPageMain.ThemesEnabled = false;
			// 
			// grpBoxGroupType
			// 
			this.grpBoxGroupType.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom) 
				| System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right)));
			this.grpBoxGroupType.Controls.Add(this.cbService);
			this.grpBoxGroupType.Controls.Add(this.dtToDate);
			this.grpBoxGroupType.Controls.Add(this.dtFromDate);
			this.grpBoxGroupType.Controls.Add(this.txtNumberNotification);
			this.grpBoxGroupType.Controls.Add(this.lblNotfyExceed);
			this.grpBoxGroupType.Controls.Add(this.lblToTime);
			this.grpBoxGroupType.Controls.Add(this.lblFromTime);
			this.grpBoxGroupType.Controls.Add(this.lblSubstituteTime);
			this.grpBoxGroupType.Controls.Add(this.lblService);
			this.grpBoxGroupType.Controls.Add(this.txtNotificationID);
			this.grpBoxGroupType.Controls.Add(this.lblNotifId);
			this.grpBoxGroupType.Controls.Add(this.lblSubstituteDefinition);
			this.grpBoxGroupType.Controls.Add(this.rdDestinationSub);
			this.grpBoxGroupType.Controls.Add(this.rdMultipleDestination);
			this.grpBoxGroupType.Location = new System.Drawing.Point(393, 0);
			this.grpBoxGroupType.Name = "grpBoxGroupType";
			this.grpBoxGroupType.Size = new System.Drawing.Size(448, 358);
			this.grpBoxGroupType.TabIndex = 1;
			this.grpBoxGroupType.TabStop = false;
			this.grpBoxGroupType.Text = "Group Type";
			// 
			// cbService
			// 
			this.cbService.AccessibleName = "";
			this.cbService.AllowNewText = false;
			this.cbService.AllowWildCards = true;
			// 
			// cbService.AutoCompleteControl
			// 
			this.cbService.AutoCompleteControl.AccessibleDescription = null;
			this.cbService.AutoCompleteControl.AccessibleName = null;
			this.cbService.AutoCompleteControl.AccessibleRole = System.Windows.Forms.AccessibleRole.None;
			this.cbService.AutoCompleteControl.AdjustHeightToItemCount = true;
			this.cbService.AutoCompleteControl.AutoAddItem = false;
			this.cbService.AutoCompleteControl.AutoSerialize = true;
			this.cbService.AutoCompleteControl.CategoryName = "";
			this.cbService.AutoCompleteControl.ChangeDataManagerPosition = true;
			this.cbService.AutoCompleteControl.OverrideCombo = true;
			this.cbService.AutoCompleteControl.ParentForm = this.grpBoxGroupType;
			this.cbService.AutoCompleteControl.PreferredHeight = 200;
			this.cbService.AutoCompleteControl.ShowCloseButton = true;
			this.cbService.AutoCompleteControl.ShowGripper = true;
			this.cbService.DropDownWidth = 40;
			this.cbService.Enabled = false;
			this.cbService.FieldName = NorthGrum.CommandPoint.Validators.GenericValidators.FieldNameType.POIState;
			this.cbService.ItemHeight = 16;
			this.cbService.Location = new System.Drawing.Point(208, 136);
			this.cbService.Name = "cbService";
			this.cbService.ParentForm = this.grpBoxGroupType;
			this.cbService.ReadOnly = false;
			this.cbService.Size = new System.Drawing.Size(144, 24);
			this.cbService.TabIndex = 6;
			this.cbService.Leave += new System.EventHandler(this.cbService_Leave);
			this.cbService.Enter += new System.EventHandler(this.cbService_Enter);
			// 
			// dtToDate
			// 
			this.dtToDate.AccessibleName = "To Date Input";
			// 
			// dtToDate.Calendar
			// 
			this.dtToDate.Calendar.AllowMultipleSelection = false;
			this.dtToDate.Calendar.Culture = new System.Globalization.CultureInfo("");
			this.dtToDate.Calendar.DaysFont = new System.Drawing.Font("Verdana", 8F);
			this.dtToDate.Calendar.DaysHeaderInterior = new Syncfusion.Drawing.BrushInfo(Syncfusion.Drawing.GradientStyle.Vertical, System.Drawing.Color.PeachPuff, System.Drawing.Color.AntiqueWhite);
			this.dtToDate.Calendar.Dock = System.Windows.Forms.DockStyle.Fill;
			this.dtToDate.Calendar.Font = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.dtToDate.Calendar.ForeColor = System.Drawing.SystemColors.ControlText;
			this.dtToDate.Calendar.Location = new System.Drawing.Point(0, 0);
			this.dtToDate.Calendar.MaxValue = new System.DateTime(9999, 12, 31, 23, 59, 59, 999);
			this.dtToDate.Calendar.MinValue = new System.DateTime(1753, 1, 1, 0, 0, 0, 0);
			this.dtToDate.Calendar.Name = "monthCalendar";
			// 
			// dtToDate.Calendar.NoneButton
			// 
			this.dtToDate.Calendar.NoneButton.Location = new System.Drawing.Point(194, 0);
			this.dtToDate.Calendar.Size = new System.Drawing.Size(266, 174);
			this.dtToDate.Calendar.SizeToFit = true;
			this.dtToDate.Calendar.Style = Syncfusion.Windows.Forms.VisualStyle.Default;
			this.dtToDate.Calendar.TabIndex = 0;
			// 
			// dtToDate.Calendar.TodayButton
			// 
			this.dtToDate.Calendar.TodayButton.Location = new System.Drawing.Point(0, 0);
			this.dtToDate.Calendar.TodayButton.Size = new System.Drawing.Size(194, 20);
			this.dtToDate.CalendarFont = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.dtToDate.CustomFormat = "HH:mm:ss";
			this.dtToDate.Enabled = false;
			this.dtToDate.Format = System.Windows.Forms.DateTimePickerFormat.Custom;
			this.dtToDate.Location = new System.Drawing.Point(208, 240);
			this.dtToDate.MaxValue = new System.DateTime(9999, 12, 31, 23, 59, 59, 999);
			this.dtToDate.MinDate = new System.DateTime(1753, 1, 1, 0, 0, 0, 0);
			this.dtToDate.Name = "dtToDate";
			this.dtToDate.NullString = "";
			this.dtToDate.ShowCheckBox = false;
			this.dtToDate.ShowDropButton = false;
			this.dtToDate.Size = new System.Drawing.Size(88, 20);
			this.dtToDate.TabIndex = 11;
			this.dtToDate.ThemesEnabled = true;
			this.dtToDate.Value = new System.DateTime(2005, 11, 7, 13, 4, 19, 499);
			this.dtToDate.Validating += new System.ComponentModel.CancelEventHandler(this.dtToDate_Validating);
			// 
			// dtFromDate
			// 
			this.dtFromDate.AccessibleName = "From Date Input";
			// 
			// dtFromDate.Calendar
			// 
			this.dtFromDate.Calendar.AllowMultipleSelection = false;
			this.dtFromDate.Calendar.Culture = new System.Globalization.CultureInfo("");
			this.dtFromDate.Calendar.DaysFont = new System.Drawing.Font("Verdana", 8F);
			this.dtFromDate.Calendar.DaysHeaderInterior = new Syncfusion.Drawing.BrushInfo(Syncfusion.Drawing.GradientStyle.Vertical, System.Drawing.Color.PeachPuff, System.Drawing.Color.AntiqueWhite);
			this.dtFromDate.Calendar.Dock = System.Windows.Forms.DockStyle.Fill;
			this.dtFromDate.Calendar.Font = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.dtFromDate.Calendar.ForeColor = System.Drawing.SystemColors.ControlText;
			this.dtFromDate.Calendar.Location = new System.Drawing.Point(0, 0);
			this.dtFromDate.Calendar.MaxValue = new System.DateTime(9999, 12, 31, 23, 59, 59, 999);
			this.dtFromDate.Calendar.MinValue = new System.DateTime(1753, 1, 1, 0, 0, 0, 0);
			this.dtFromDate.Calendar.Name = "monthCalendar";
			// 
			// dtFromDate.Calendar.NoneButton
			// 
			this.dtFromDate.Calendar.NoneButton.Location = new System.Drawing.Point(194, 0);
			this.dtFromDate.Calendar.Size = new System.Drawing.Size(266, 174);
			this.dtFromDate.Calendar.SizeToFit = true;
			this.dtFromDate.Calendar.Style = Syncfusion.Windows.Forms.VisualStyle.Default;
			this.dtFromDate.Calendar.TabIndex = 0;
			// 
			// dtFromDate.Calendar.TodayButton
			// 
			this.dtFromDate.Calendar.TodayButton.Location = new System.Drawing.Point(0, 0);
			this.dtFromDate.Calendar.TodayButton.Size = new System.Drawing.Size(194, 20);
			this.dtFromDate.CalendarFont = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.dtFromDate.CustomFormat = "HH:mm:ss";
			this.dtFromDate.Enabled = false;
			this.dtFromDate.Format = System.Windows.Forms.DateTimePickerFormat.Custom;
			this.dtFromDate.Location = new System.Drawing.Point(208, 208);
			this.dtFromDate.MaxValue = new System.DateTime(9999, 12, 31, 23, 59, 59, 999);
			this.dtFromDate.MinDate = new System.DateTime(1753, 1, 1, 0, 0, 0, 0);
			this.dtFromDate.Name = "dtFromDate";
			this.dtFromDate.NullString = "";
			this.dtFromDate.ShowCheckBox = false;
			this.dtFromDate.ShowDropButton = false;
			this.dtFromDate.Size = new System.Drawing.Size(88, 20);
			this.dtFromDate.TabIndex = 9;
			this.dtFromDate.ThemesEnabled = true;
			this.dtFromDate.Value = new System.DateTime(2005, 11, 7, 13, 4, 19, 499);
			this.dtFromDate.Validating += new System.ComponentModel.CancelEventHandler(this.dtFromDate_Validating);
			// 
			// txtNumberNotification
			// 
			this.txtNumberNotification.Enabled = false;
			this.txtNumberNotification.FieldName = NorthGrum.CommandPoint.Validators.GenericValidators.FieldNameType.Accountname;
			this.txtNumberNotification.Font = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.txtNumberNotification.Location = new System.Drawing.Point(288, 280);
			this.txtNumberNotification.MaxLength = 2;
			this.txtNumberNotification.Name = "txtNumberNotification";
			this.txtNumberNotification.Size = new System.Drawing.Size(64, 23);
			this.txtNumberNotification.TabIndex = 13;
			this.txtNumberNotification.Text = "";
			this.txtNumberNotification.KeyPress += new System.Windows.Forms.KeyPressEventHandler(this.txtNumberNotification_KeyPress);
			this.txtNumberNotification.Validating += new System.ComponentModel.CancelEventHandler(this.txtNumberNotification_Validating);
			// 
			// lblNotfyExceed
			// 
			this.lblNotfyExceed.Font = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.lblNotfyExceed.Location = new System.Drawing.Point(16, 280);
			this.lblNotfyExceed.Name = "lblNotfyExceed";
			this.lblNotfyExceed.Size = new System.Drawing.Size(272, 23);
			this.lblNotfyExceed.TabIndex = 12;
			// SIRT 30104
			this.lblNotfyExceed.Text = "or when the number of &notifications exceeds";
			// 
			// lblToTime
			// 
			this.lblToTime.AutoSize = true;
			this.lblToTime.Font = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.lblToTime.Location = new System.Drawing.Point(165, 240);
			this.lblToTime.Name = "lblToTime";
			this.lblToTime.RightToLeft = System.Windows.Forms.RightToLeft.Yes;
			this.lblToTime.Size = new System.Drawing.Size(20, 19);
			this.lblToTime.TabIndex = 10;
			// SIRT 30104
			this.lblToTime.Text = "&To";
			// 
			// lblFromTime
			// 
			this.lblFromTime.AutoSize = true;
			this.lblFromTime.Font = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.lblFromTime.Location = new System.Drawing.Point(150, 208);
			this.lblFromTime.Name = "lblFromTime";
			this.lblFromTime.RightToLeft = System.Windows.Forms.RightToLeft.Yes;
			this.lblFromTime.Size = new System.Drawing.Size(35, 19);
			this.lblFromTime.TabIndex = 8;
			// SIRT 30104
			this.lblFromTime.Text = "&From";
			// 
			// lblSubstituteTime
			// 
			this.lblSubstituteTime.Font = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.lblSubstituteTime.Location = new System.Drawing.Point(16, 176);
			this.lblSubstituteTime.Name = "lblSubstituteTime";
			this.lblSubstituteTime.Size = new System.Drawing.Size(192, 23);
			this.lblSubstituteTime.TabIndex = 7;
			this.lblSubstituteTime.Text = "Substitute within Time Range";
			// 
			// lblService
			// 
			this.lblService.AutoSize = true;
			this.lblService.Font = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.lblService.Location = new System.Drawing.Point(131, 136);
			this.lblService.Name = "lblService";
			this.lblService.RightToLeft = System.Windows.Forms.RightToLeft.Yes;
			this.lblService.Size = new System.Drawing.Size(54, 19);
			this.lblService.TabIndex = 5;
			// SIRT 30104
			this.lblService.Text = "Ser&vice*";
			// 
			// txtNotificationID
			// 
			this.txtNotificationID.Enabled = false;
			this.txtNotificationID.FieldName = NorthGrum.CommandPoint.Validators.GenericValidators.FieldNameType.Accountname;
			this.txtNotificationID.Font = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.txtNotificationID.Location = new System.Drawing.Point(208, 96);
			this.txtNotificationID.MaxLength = 50;
			this.txtNotificationID.Name = "txtNotificationID";
			this.txtNotificationID.Size = new System.Drawing.Size(144, 23);
			this.txtNotificationID.TabIndex = 4;
			this.txtNotificationID.Text = "";
			this.txtNotificationID.Leave += new System.EventHandler(this.txtNotificationID_Leave);
			// 
			// lblNotifId
			// 
			this.lblNotifId.AutoSize = true;
			this.lblNotifId.Font = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.lblNotifId.Location = new System.Drawing.Point(88, 96);
			this.lblNotifId.Name = "lblNotifId";
			this.lblNotifId.RightToLeft = System.Windows.Forms.RightToLeft.Yes;
			this.lblNotifId.Size = new System.Drawing.Size(97, 19);
			this.lblNotifId.TabIndex = 3;
			// SIRT 30104
			this.lblNotifId.Text = "Notification &ID*";
			// 
			// lblSubstituteDefinition
			// 
			this.lblSubstituteDefinition.AutoSize = true;
			this.lblSubstituteDefinition.Font = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.lblSubstituteDefinition.Location = new System.Drawing.Point(72, 64);
			this.lblSubstituteDefinition.Name = "lblSubstituteDefinition";
			this.lblSubstituteDefinition.Size = new System.Drawing.Size(125, 19);
			this.lblSubstituteDefinition.TabIndex = 2;
			this.lblSubstituteDefinition.Text = "Substitute Definition";
			// 
			// rdDestinationSub
			// 
			this.rdDestinationSub.Location = new System.Drawing.Point(208, 32);
			this.rdDestinationSub.Name = "rdDestinationSub";
			// SIRT 30104
			this.rdDestinationSub.Size = new System.Drawing.Size(174, 24);
			this.rdDestinationSub.TabIndex = 1;
			// SIRT 30104
			this.rdDestinationSub.Text = "Destin&ation Substitution";
			this.rdDestinationSub.CheckedChanged += new System.EventHandler(this.rdDestinationSub_CheckedChanged);
			// 
			// rdMultipleDestination
			// 
			this.rdMultipleDestination.Location = new System.Drawing.Point(16, 32);
			this.rdMultipleDestination.Name = "rdMultipleDestination";
			this.rdMultipleDestination.Size = new System.Drawing.Size(180, 24);
			this.rdMultipleDestination.TabIndex = 0;
			// SIRT 30104
			this.rdMultipleDestination.Text = "M&ultiple Destinations";
			// 
			// grpBoxResults
			// 
			this.grpBoxResults.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom) 
				| System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right)));
			this.grpBoxResults.Controls.Add(this.gdbgResults);
			this.grpBoxResults.Location = new System.Drawing.Point(0, 0);
			this.grpBoxResults.Name = "grpBoxResults";
			this.grpBoxResults.Size = new System.Drawing.Size(392, 358);
			this.grpBoxResults.TabIndex = 0;
			this.grpBoxResults.TabStop = false;
			this.grpBoxResults.Text = "Groups";
			// 
			// gdbgResults
			// 
			this.gdbgResults.AllowDragSelectedCols = true;
			this.gdbgResults.Dock = System.Windows.Forms.DockStyle.Fill;
			this.gdbgResults.EnableRemove = false;
			this.gdbgResults.Font = new System.Drawing.Font("Tahoma", 9.75F);
			this.gdbgResults.GridBoundColumns.AddRange(new Syncfusion.Windows.Forms.Grid.GridBoundColumn[] {
																											   this.notificationType,
																											   this.notificationGroupID});
			this.gdbgResults.Location = new System.Drawing.Point(3, 19);
			this.gdbgResults.Name = "gdbgResults";
			this.gdbgResults.OptimizeInsertRemoveCells = true;
			this.gdbgResults.ShowCurrentCellBorderBehavior = Syncfusion.Windows.Forms.Grid.GridShowCurrentCellBorder.GrayWhenLostFocus;
			this.gdbgResults.Size = new System.Drawing.Size(386, 336);
			this.gdbgResults.SmartSizeBox = false;
			this.gdbgResults.SortBehavior = Syncfusion.Windows.Forms.Grid.GridSortBehavior.DoubleClick;
			this.gdbgResults.TabIndex = 0;
			gridStyleInfo1.Font.Bold = false;
			gridStyleInfo1.Font.Facename = "Tahoma";
			gridStyleInfo1.Font.Italic = false;
			gridStyleInfo1.Font.Size = 9.75F;
			gridStyleInfo1.Font.Strikeout = false;
			gridStyleInfo1.Font.Underline = false;
			this.gdbgResults.TableStyle = gridStyleInfo1;
			this.gdbgResults.UseListChangedEvent = true;
			this.gdbgResults.CurrentCellAcceptedChanges += new System.ComponentModel.CancelEventHandler(this.gdbgResults_CurrentCellAcceptedChanges);
			this.gdbgResults.RowLeave += new Syncfusion.Windows.Forms.Grid.GridRowEventHandler(this.gdbgResults_RowLeave);
			this.gdbgResults.WrapCellNextControlInForm += new Syncfusion.Windows.Forms.Grid.GridWrapCellNextControlInFormEventHandler(this.gdbgResults_WrapCellNextControlInForm);
			this.gdbgResults.CurrentCellControlKeyMessage += new Syncfusion.Windows.Forms.Grid.GridCurrentCellControlKeyMessageEventHandler(this.gdbgResults_CurrentCellControlKeyMessage);
			this.gdbgResults.CurrentCellShowingDropDown += new Syncfusion.Windows.Forms.Grid.GridCurrentCellShowingDropDownEventHandler(this.gdbgResults_CurrentCellShowingDropDown);
			this.gdbgResults.CurrentCellKeyPress += new System.Windows.Forms.KeyPressEventHandler(this.gdbgResults_CurrentCellKeyPress);
			this.gdbgResults.RowEnter += new Syncfusion.Windows.Forms.Grid.GridRowEventHandler(this.gdbgResults_RowEnter);
			this.gdbgResults.Enter += new System.EventHandler(this.gridDataBoundGrid_Enter);
			this.gdbgResults.CurrentCellValidating += new System.ComponentModel.CancelEventHandler(this.gdbgResults_CurrentCellValidating);
			this.gdbgResults.CurrentCellActivated += new System.EventHandler(this.gdbgResults_CurrentCellActivated);
			// 
			// notificationType
			// 
			this.notificationType.HeaderText = "Notification Type*";
			this.notificationType.MappingName = "TypeName";
			this.notificationType.StyleInfo.CellType = "NGGridListCell";
			this.notificationType.StyleInfo.DropDownStyle = Syncfusion.Windows.Forms.Grid.GridDropDownStyle.AutoComplete;
			// 
			// notificationGroupID
			// 
			this.notificationGroupID.HeaderText = "Notification Group ID*";
			this.notificationGroupID.MappingName = "GroupId";
			this.notificationGroupID.StyleInfo.MaxLength = 10;
			// 
			// tabPageNotification
			// 
			this.tabPageNotification.Controls.Add(this.grpBoxGrpNotification);
			this.tabPageNotification.Font = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.tabPageNotification.IsTransparent = false;
			this.tabPageNotification.Location = new System.Drawing.Point(1, 30);
			this.tabPageNotification.Name = "tabPageNotification";
			this.tabPageNotification.Size = new System.Drawing.Size(841, 358);
			this.tabPageNotification.TabIndex = 1;
			this.tabPageNotification.Text = "&Group Notification";
			this.tabPageNotification.ThemesEnabled = false;
			// 
			// grpBoxGrpNotification
			// 
			this.grpBoxGrpNotification.Controls.Add(this.grdGrpNotification);
			this.grpBoxGrpNotification.Dock = System.Windows.Forms.DockStyle.Fill;
			this.grpBoxGrpNotification.Location = new System.Drawing.Point(0, 0);
			this.grpBoxGrpNotification.Name = "grpBoxGrpNotification";
			this.grpBoxGrpNotification.Size = new System.Drawing.Size(841, 358);
			this.grpBoxGrpNotification.TabIndex = 0;
			this.grpBoxGrpNotification.TabStop = false;
			this.grpBoxGrpNotification.Text = "Group Members";
			// 
			// grdGrpNotification
			// 
			this.grdGrpNotification.AllowDragSelectedCols = true;
			this.grdGrpNotification.Dock = System.Windows.Forms.DockStyle.Fill;
			this.grdGrpNotification.Font = new System.Drawing.Font("Tahoma", 9.75F);
			this.grdGrpNotification.GridBoundColumns.AddRange(new Syncfusion.Windows.Forms.Grid.GridBoundColumn[] {
																													  this.colResourceType,
																													  this.colDescription,
																													  this.colResponseType,
																													  this.colResponseID,
																													  this.colNotificationNumber,
																													  this.colDisplayName,
																													  this.colCongrpid,
																													  this.colResCongrpID});
			this.grdGrpNotification.Location = new System.Drawing.Point(3, 19);
			this.grdGrpNotification.Name = "grdGrpNotification";
			this.grdGrpNotification.OptimizeInsertRemoveCells = true;
			this.grdGrpNotification.ShowCurrentCellBorderBehavior = Syncfusion.Windows.Forms.Grid.GridShowCurrentCellBorder.GrayWhenLostFocus;
			this.grdGrpNotification.Size = new System.Drawing.Size(835, 336);
			this.grdGrpNotification.SmartSizeBox = false;
			this.grdGrpNotification.SortBehavior = Syncfusion.Windows.Forms.Grid.GridSortBehavior.DoubleClick;
			this.grdGrpNotification.TabIndex = 0;
			gridStyleInfo2.Font.Bold = false;
			gridStyleInfo2.Font.Facename = "Tahoma";
			gridStyleInfo2.Font.Italic = false;
			gridStyleInfo2.Font.Size = 9.75F;
			gridStyleInfo2.Font.Strikeout = false;
			gridStyleInfo2.Font.Underline = false;
			this.grdGrpNotification.TableStyle = gridStyleInfo2;
			this.grdGrpNotification.UseListChangedEvent = true;
			this.grdGrpNotification.CurrentCellAcceptedChanges += new System.ComponentModel.CancelEventHandler(this.grdGrpNotification_CurrentCellAcceptedChanges);
			this.grdGrpNotification.RowLeave += new Syncfusion.Windows.Forms.Grid.GridRowEventHandler(this.gdbgResults_RowLeave);
			this.grdGrpNotification.CurrentCellShowingDropDown += new Syncfusion.Windows.Forms.Grid.GridCurrentCellShowingDropDownEventHandler(this.grdGrpNotification_CurrentCellShowingDropDown);
			this.grdGrpNotification.CurrentCellKeyPress += new System.Windows.Forms.KeyPressEventHandler(this.gdbgResults_CurrentCellKeyPress);
			this.grdGrpNotification.CurrentCellValidating += new System.ComponentModel.CancelEventHandler(this.grdGrpNotification_CurrentCellValidating);
			this.grdGrpNotification.CurrentCellActivated += new System.EventHandler(this.grdGrpNotification_CurrentCellActivated);
			// 
			// colResourceType
			// 
			this.colResourceType.HeaderText = "Resource Type*";
			this.colResourceType.MappingName = "ResourceType";
			this.colResourceType.StyleInfo.CellType = "NGGridListCell";
			this.colResourceType.StyleInfo.DropDownStyle = Syncfusion.Windows.Forms.Grid.GridDropDownStyle.AutoComplete;
			this.colResourceType.StyleInfo.ValueMember = "VALUE";
			// 
			// colDescription
			// 
			this.colDescription.HeaderText = "Resource ID*";
			this.colDescription.MappingName = "Description";
			this.colDescription.StyleInfo.CellType = "NGGridListCell";
			this.colDescription.StyleInfo.DropDownStyle = Syncfusion.Windows.Forms.Grid.GridDropDownStyle.AutoComplete;
			this.colDescription.StyleInfo.ValueMember = "VALUE";
			// 
			// colResponseType
			// 
			this.colResponseType.MappingName = "TypeName";
			// 
			// colResponseID
			// 
			this.colResponseID.MappingName = "ResourceId";
			// 
			// colNotificationNumber
			// 
			this.colNotificationNumber.MappingName = "NotificationNumber";
			// 
			// colDisplayName
			// 
			this.colDisplayName.MappingName = "DisplayName";
			// 
			// tabPageHistory
			// 
			this.tabPageHistory.Controls.Add(this.cP_HistoryDisplayNGP);
			this.tabPageHistory.Font = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.tabPageHistory.IsTransparent = false;
			this.tabPageHistory.Location = new System.Drawing.Point(1, 30);
			this.tabPageHistory.Name = "tabPageHistory";
			this.tabPageHistory.Size = new System.Drawing.Size(841, 336);
			this.tabPageHistory.TabIndex = 3;
			this.tabPageHistory.Text = "&History";
			this.tabPageHistory.ThemesEnabled = false;
			// 
			// cP_HistoryDisplayNGP
			// 
			this.cP_HistoryDisplayNGP.Location = new System.Drawing.Point(46, 48);
			this.cP_HistoryDisplayNGP.Name = "cP_HistoryDisplayNGP";
			this.cP_HistoryDisplayNGP.Size = new System.Drawing.Size(584, 168);
			this.cP_HistoryDisplayNGP.TabIndex = 0;
			// 
			// ddlAgency
			// 
			this.ddlAgency.AccessibleName = "Agency Input";
			this.ddlAgency.AllowNewText = false;
			this.ddlAgency.AllowWildCards = true;
			// 
			// ddlAgency.AutoCompleteControl
			// 
			this.ddlAgency.AutoCompleteControl.AccessibleDescription = null;
			this.ddlAgency.AutoCompleteControl.AccessibleName = null;
			this.ddlAgency.AutoCompleteControl.AccessibleRole = System.Windows.Forms.AccessibleRole.None;
			this.ddlAgency.AutoCompleteControl.AdjustHeightToItemCount = true;
			this.ddlAgency.AutoCompleteControl.AutoAddItem = false;
			this.ddlAgency.AutoCompleteControl.AutoSerialize = true;
			this.ddlAgency.AutoCompleteControl.CategoryName = "";
			this.ddlAgency.AutoCompleteControl.ChangeDataManagerPosition = true;
			this.ddlAgency.AutoCompleteControl.OverrideCombo = true;
			this.ddlAgency.AutoCompleteControl.ParentForm = this;
			this.ddlAgency.AutoCompleteControl.PreferredHeight = 200;
			this.ddlAgency.AutoCompleteControl.ShowCloseButton = true;
			this.ddlAgency.AutoCompleteControl.ShowColumnHeader = true;
			this.ddlAgency.AutoCompleteControl.ShowGripper = true;
			this.ddlAgency.DropDownWidth = 96;
			this.ddlAgency.FieldName = NorthGrum.CommandPoint.Validators.GenericValidators.FieldNameType.Accountname;
			this.ddlAgency.Font = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.ddlAgency.ItemHeight = 16;
			this.ddlAgency.Location = new System.Drawing.Point(84, 68);
			this.ddlAgency.Name = "ddlAgency";
			this.ddlAgency.ParentForm = this;
			this.ddlAgency.ReadOnly = false;
			this.ddlAgency.Size = new System.Drawing.Size(121, 24);
			this.ddlAgency.TabIndex = 2;
			this.ddlAgency.Validated += new System.EventHandler(this.ddlAgency_Validated);
			this.ddlAgency.TextChanged += new System.EventHandler(this.ddlAgency_TextChanged);
			// 
			// txtAgenciesInCongrpid
			// 
			this.txtAgenciesInCongrpid.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right)));
			this.txtAgenciesInCongrpid.FieldName = NorthGrum.CommandPoint.Validators.GenericValidators.FieldNameType.Accountname;
			this.txtAgenciesInCongrpid.Font = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.txtAgenciesInCongrpid.Location = new System.Drawing.Point(589, 68);
			this.txtAgenciesInCongrpid.Name = "txtAgenciesInCongrpid";
			this.txtAgenciesInCongrpid.ReadOnly = true;
			this.txtAgenciesInCongrpid.Size = new System.Drawing.Size(253, 23);
			this.txtAgenciesInCongrpid.TabIndex = 6;
			this.txtAgenciesInCongrpid.TabStop = false;
			this.txtAgenciesInCongrpid.Text = "";
			// 
			// txtCongrpid
			// 
			this.txtCongrpid.FieldName = NorthGrum.CommandPoint.Validators.GenericValidators.FieldNameType.Accountname;
			this.txtCongrpid.Font = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.txtCongrpid.Location = new System.Drawing.Point(293, 68);
			this.txtCongrpid.Name = "txtCongrpid";
			this.txtCongrpid.ReadOnly = true;
			this.txtCongrpid.Size = new System.Drawing.Size(136, 23);
			this.txtCongrpid.TabIndex = 4;
			this.txtCongrpid.TabStop = false;
			this.txtCongrpid.Text = "";
			// 
			// lblAgencyGroup
			// 
			this.lblAgencyGroup.Font = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.lblAgencyGroup.Location = new System.Drawing.Point(434, 68);
			this.lblAgencyGroup.Name = "lblAgencyGroup";
			this.lblAgencyGroup.Size = new System.Drawing.Size(150, 23);
			this.lblAgencyGroup.TabIndex = 5;
			this.lblAgencyGroup.Text = "Agencies in Data Group";
			// 
			// lblDataGroup
			// 
			this.lblDataGroup.Font = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.lblDataGroup.Location = new System.Drawing.Point(210, 68);
			this.lblDataGroup.Name = "lblDataGroup";
			this.lblDataGroup.Size = new System.Drawing.Size(78, 23);
			this.lblDataGroup.TabIndex = 3;
			this.lblDataGroup.Text = "Data Group";
			// 
			// lblAgency
			// 
			this.lblAgency.Font = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.lblAgency.Location = new System.Drawing.Point(22, 68);
			this.lblAgency.Name = "lblAgency";
			this.lblAgency.Size = new System.Drawing.Size(57, 23);
			this.lblAgency.TabIndex = 1;
			this.lblAgency.Text = "Agency";
			// 
			// lblNotificationType
			// 
			this.lblNotificationType.Font = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.lblNotificationType.Location = new System.Drawing.Point(24, 104);
			this.lblNotificationType.Name = "lblNotificationType";
			this.lblNotificationType.Size = new System.Drawing.Size(104, 23);
			this.lblNotificationType.TabIndex = 7;
			this.lblNotificationType.Text = "Notification Type";
			// 
			// ddlNotificationType
			// 
			this.ddlNotificationType.AccessibleName = "Agency Input";
			this.ddlNotificationType.AllowNewText = false;
			this.ddlNotificationType.AllowWildCards = true;
			// 
			// ddlNotificationType.AutoCompleteControl
			// 
			this.ddlNotificationType.AutoCompleteControl.AccessibleDescription = null;
			this.ddlNotificationType.AutoCompleteControl.AccessibleName = null;
			this.ddlNotificationType.AutoCompleteControl.AccessibleRole = System.Windows.Forms.AccessibleRole.None;
			this.ddlNotificationType.AutoCompleteControl.AdjustHeightToItemCount = true;
			this.ddlNotificationType.AutoCompleteControl.AutoAddItem = false;
			this.ddlNotificationType.AutoCompleteControl.AutoSerialize = true;
			this.ddlNotificationType.AutoCompleteControl.CategoryName = "";
			this.ddlNotificationType.AutoCompleteControl.ChangeDataManagerPosition = true;
			this.ddlNotificationType.AutoCompleteControl.OverrideCombo = true;
			this.ddlNotificationType.AutoCompleteControl.ParentForm = this;
			this.ddlNotificationType.AutoCompleteControl.PreferredHeight = 200;
			this.ddlNotificationType.AutoCompleteControl.ShowCloseButton = true;
			this.ddlNotificationType.AutoCompleteControl.ShowColumnHeader = true;
			this.ddlNotificationType.AutoCompleteControl.ShowGripper = true;
			this.ddlNotificationType.DropDownWidth = 96;
			this.ddlNotificationType.FieldName = NorthGrum.CommandPoint.Validators.GenericValidators.FieldNameType.Accountname;
			this.ddlNotificationType.Font = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.ddlNotificationType.ItemHeight = 16;
			this.ddlNotificationType.Location = new System.Drawing.Point(136, 104);
			this.ddlNotificationType.Name = "ddlNotificationType";
			this.ddlNotificationType.ParentForm = this;
			this.ddlNotificationType.ReadOnly = false;
			this.ddlNotificationType.Size = new System.Drawing.Size(121, 24);
			this.ddlNotificationType.TabIndex = 8;
			// 
			// lblNotificationGroupId
			// 
			this.lblNotificationGroupId.Font = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.lblNotificationGroupId.Location = new System.Drawing.Point(280, 104);
			this.lblNotificationGroupId.Name = "lblNotificationGroupId";
			this.lblNotificationGroupId.Size = new System.Drawing.Size(136, 23);
			this.lblNotificationGroupId.TabIndex = 9;
			this.lblNotificationGroupId.Text = "Notification Group ID";
			// 
			// txtNotificationGrpID
			// 
			this.txtNotificationGrpID.FieldName = NorthGrum.CommandPoint.Validators.GenericValidators.FieldNameType.Accountname;
			this.txtNotificationGrpID.Font = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.txtNotificationGrpID.Location = new System.Drawing.Point(424, 104);
			this.txtNotificationGrpID.MaxLength = 10;
			this.txtNotificationGrpID.Name = "txtNotificationGrpID";
			this.txtNotificationGrpID.Size = new System.Drawing.Size(136, 23);
			this.txtNotificationGrpID.TabIndex = 10;
			this.txtNotificationGrpID.Text = "";
			// 
			// cP_FormButtonsNGP
			// 
			this.cP_FormButtonsNGP.AddButtonEnabled = false;
			this.cP_FormButtonsNGP.AddButtonVisible = false;
			this.cP_FormButtonsNGP.BackColor = System.Drawing.SystemColors.Control;
			this.cP_FormButtonsNGP.ClassName = "CADBaseNGP";
			this.cP_FormButtonsNGP.ClearButtonEnabled = true;
			this.cP_FormButtonsNGP.ClearButtonVisible = true;
			this.cP_FormButtonsNGP.DeleteButtonEnabled = true;
			this.cP_FormButtonsNGP.DeleteButtonVisible = true;
			this.cP_FormButtonsNGP.DisplayButtonEnabled = false;
			this.cP_FormButtonsNGP.DisplayButtonVisible = false;
			this.cP_FormButtonsNGP.Dock = System.Windows.Forms.DockStyle.Bottom;
			this.cP_FormButtonsNGP.ExitButtonEnabled = true;
			this.cP_FormButtonsNGP.ExitButtonVisible = true;
			this.cP_FormButtonsNGP.Font = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.cP_FormButtonsNGP.InquiryButtonEnabled = true;
			this.cP_FormButtonsNGP.InquiryButtonVisible = true;
			this.cP_FormButtonsNGP.Location = new System.Drawing.Point(0, 543);
			this.cP_FormButtonsNGP.Name = "cP_FormButtonsNGP";
			this.cP_FormButtonsNGP.OptionButtonVisible = true;
			this.cP_FormButtonsNGP.OutputButtonEnabled = true;
			this.cP_FormButtonsNGP.OutputButtonVisible = true;
			this.cP_FormButtonsNGP.RevertButtonEnabled = false;
			this.cP_FormButtonsNGP.RevertButtonVisible = false;
			this.cP_FormButtonsNGP.Size = new System.Drawing.Size(860, 40);
			this.cP_FormButtonsNGP.TabIndex = 13;
			this.cP_FormButtonsNGP.UpdateButtonEnabled = false;
			this.cP_FormButtonsNGP.UpdateButtonVisible = false;
			this.cP_FormButtonsNGP.DeleteButtonClicked += new System.EventHandler(this.cP_FormButtonsNGP_DeleteButtonClicked);
			this.cP_FormButtonsNGP.ClearButtonClicked += new System.EventHandler(this.cP_FormButtonsNGP_ClearButtonClicked);
			this.cP_FormButtonsNGP.InquiryButtonClicked += new System.EventHandler(this.cP_FormButtonsNGP_InquiryButtonClicked);
			this.cP_FormButtonsNGP.OutputButtonClicked += new NorthGrum.CommandPoint.UIControls.BaseControls.CP_FormButtons.OutputEventHandler(this.cP_FormButtonsNGP_OutputButtonClicked);
			// 
			// btnSave
			// 
			this.btnSave.FlatStyle = System.Windows.Forms.FlatStyle.System;
			this.btnSave.Font = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.btnSave.Location = new System.Drawing.Point(128, 552);
			this.btnSave.Name = "btnSave";
			this.btnSave.Size = new System.Drawing.Size(72, 24);
			this.btnSave.TabIndex = 12;
			this.btnSave.Text = "&Save";
			this.btnSave.Click += new System.EventHandler(this.btnSave_Click);
			// 
			// errorProvider
			// 
			this.errorProvider.ContainerControl = this;
			// 
			// colCongrpid
			// 
			this.colCongrpid.MappingName = "PrimaryResCng";
			// 
			// colResCongrpID
			// 
			this.colResCongrpID.MappingName = "SecondaryResCng";
			// 
			// FormNGP
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(860, 583);
			this.Controls.Add(this.btnSave);
			this.Controls.Add(this.cP_FormButtonsNGP);
			this.Controls.Add(this.txtNotificationGrpID);
			this.Controls.Add(this.lblNotificationGroupId);
			this.Controls.Add(this.ddlNotificationType);
			this.Controls.Add(this.lblNotificationType);
			this.Controls.Add(this.ddlAgency);
			this.Controls.Add(this.txtAgenciesInCongrpid);
			this.Controls.Add(this.txtCongrpid);
			this.Controls.Add(this.lblAgencyGroup);
			this.Controls.Add(this.lblDataGroup);
			this.Controls.Add(this.lblAgency);
			this.Controls.Add(this.tabControlNGP);
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedSingle;
			this.MinimumSize = new System.Drawing.Size(866, 588);
			this.Name = "FormNGP";
			this.Text = "NGP - Notification Group Definition";
			this.Closing += new System.ComponentModel.CancelEventHandler(this.FormNGP_Closing);
			this.Load += new System.EventHandler(this.FormNGP_Load);
			this.Controls.SetChildIndex(this.tabControlNGP, 0);
			this.Controls.SetChildIndex(this._commandLineControl, 0);
			this.Controls.SetChildIndex(this.lblAgency, 0);
			this.Controls.SetChildIndex(this.lblDataGroup, 0);
			this.Controls.SetChildIndex(this.lblAgencyGroup, 0);
			this.Controls.SetChildIndex(this.txtCongrpid, 0);
			this.Controls.SetChildIndex(this.txtAgenciesInCongrpid, 0);
			this.Controls.SetChildIndex(this.ddlAgency, 0);
			this.Controls.SetChildIndex(this.lblNotificationType, 0);
			this.Controls.SetChildIndex(this.ddlNotificationType, 0);
			this.Controls.SetChildIndex(this.lblNotificationGroupId, 0);
			this.Controls.SetChildIndex(this.txtNotificationGrpID, 0);
			this.Controls.SetChildIndex(this.cP_FormButtonsNGP, 0);
			this.Controls.SetChildIndex(this.btnSave, 0);
			((System.ComponentModel.ISupportInitialize)(this.tabControlNGP)).EndInit();
			this.tabControlNGP.ResumeLayout(false);
			this.tabPageMain.ResumeLayout(false);
			this.grpBoxGroupType.ResumeLayout(false);
			((System.ComponentModel.ISupportInitialize)(this.cbService.AutoCompleteControl)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.dtToDate.Calendar)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.dtToDate)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.dtFromDate.Calendar)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.dtFromDate)).EndInit();
			this.grpBoxResults.ResumeLayout(false);
			((System.ComponentModel.ISupportInitialize)(this.gdbgResults)).EndInit();
			this.tabPageNotification.ResumeLayout(false);
			this.grpBoxGrpNotification.ResumeLayout(false);
			((System.ComponentModel.ISupportInitialize)(this.grdGrpNotification)).EndInit();
			this.tabPageHistory.ResumeLayout(false);
			((System.ComponentModel.ISupportInitialize)(this.ddlAgency.AutoCompleteControl)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.ddlNotificationType.AutoCompleteControl)).EndInit();
			this.ResumeLayout(false);

		}

        #endregion

        #region Events
        /// <summary>
        /// This method is used to load the NGP form.
        /// </summary>
        /// <param name="sender">Object</param>
        /// <param name="e">Event arguements</param>
        private void FormNGP_Load(object sender, System.EventArgs e)
        {
            try
            {
                CADLog.LogDebug("Start of Event","FormNGP_Load", THIS_CLASS);
                this.ddlAgency.SelectedText = Wks.MyWks.PriAgency;
                this.AgencySetUp();
                ConfigureGrids();
                LoadComboBoxes();
                RefreshButtons();
                RefreshParentDataSource();
                ClearGroupType();
                this.btnSave.Enabled=false;
                CADLog.LogDebug("End of Event","FormNGP_Load", THIS_CLASS);
                if(GetSubstitutionDOS().ToUpper()=="YES")
                    grpBoxGroupType.Visible=true;
                else
                    grpBoxGroupType.Visible=false;
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"FormNGP_Load", THIS_CLASS);
            }
        }
        /// <summary>
        /// Handler for validating the Agency drop down.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ddlAgency_TextChanged(object sender, System.EventArgs e)
        {
            try
            {
                CADLog.LogDebug("Start of Event","ddlAgency_TextChanged", THIS_CLASS);
                agencyChanged=true;
                this.ddlAgency.TextChanged -= new System.EventHandler(this.ddlAgency_TextChanged);
                cP_FormButtonsNGP_ClearButtonClicked(null,null);
                this.ddlAgency.TextChanged += new System.EventHandler(this.ddlAgency_TextChanged);
                this.agency = ddlAgency.Text;
                agencyChanged=false;
                CADLog.LogDebug("End of Event","ddlAgency_TextChanged", THIS_CLASS);
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"ddlAgency_TextChanged", THIS_CLASS);
            }
        }
        /// <summary>
        /// Handler for validating the Agency drop down.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ddlAgency_Validated(object sender, System.EventArgs e)
        {
            try
            {
                CADLog.LogDebug("Start of Event","ddlAgency_Validated", THIS_CLASS);
                this.AgencySetUp();
                CADLog.LogDebug("End of Event","ddlAgency_Validated", THIS_CLASS);
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"ddlAgency_Validated", THIS_CLASS);
            }
        }
        /// <summary>
        /// When the main data entry collection changes, enable/disable the Add/Update buttons
        /// accordingly.
        /// </summary>
        /// <param name="sender">Object</param>
        /// <param name="e">Event Arguements</param>
        private void ResultsListChanged(object sender, ListChangedEventArgs e)
        {
            try
            {
                CADLog.LogDebug("Start of Event","ResultsListChanged", THIS_CLASS);
                this.AddNewIfEmpty((CADBaseCollection) sender);
                this.RefreshButtons();
                CADLog.LogDebug("End of Event","ResultsListChanged", THIS_CLASS);
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"ResultsListChanged", THIS_CLASS);
            }
        }

        /// <summary>
        /// When our position in the main data entry collection changes, retrieve children
        /// for the current record and refresh the datasources for the child grids.
        /// </summary>
        /// <param name="sender">Object</param>
        /// <param name="e">Event Arguments</param>
        private void PositionChanged(object sender, EventArgs e)
        {
            try
            {
                CADLog.LogDebug("Start of Event","PositionChanged", THIS_CLASS);
                this._commandLineControl.DisplayMessage(String.Empty);
                CADBase cb = (CADBase) this.CadBaseNGPObject[((BindingManagerBase) sender).Position];
                if (!cb.ChildRecordsLoaded)
                    DisplayRecord(true);
                else
                    DisplayRecord(false);
                CADLog.LogDebug("End of Event","PositionChanged", THIS_CLASS);
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"PositionChanged", THIS_CLASS);
            }

        }
		
        /// <summary>
        /// Event Handler if Delete button pressed and used to delete records.
        /// </summary>
        /// <param name="sender">Object</param>
        /// <param name="e">Event Arguements</param>
        private void cP_FormButtonsNGP_DeleteButtonClicked(object sender, EventArgs e)
        {
            try
            {
                CADLog.LogDebug("Start of Event","cP_FormButtonsNGP_DeleteButtonClicked", THIS_CLASS);
                CADBase currentObject = (CADBase) this.gdbgResults.BindingContext[this.gdbgResults.DataSource].Current;
                if (currentObject.ValidForDelete())
                {
                    currentObject.ParentCollection.Remove(currentObject);
                    currentObject.Delete();
                }
                DisplayRecord(true);
                this._commandLineControl.DisplayMessage( EclipseMessage.GetMessage(AdministrativeFormMessages.RecordDeleted));
                CADLog.LogDebug("End of Event","cP_FormButtonsNGP_DeleteButtonClicked", THIS_CLASS);
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"cP_FormButtonsNGP_DeleteButtonClicked", THIS_CLASS);
            }
        }

        /// <summary>
        /// Used to clear the displayed records.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void cP_FormButtonsNGP_ClearButtonClicked(object sender, System.EventArgs e)
        {
            try
            {
                CADLog.LogDebug("Start of Event","cP_FormButtonsNGP_ClearButtonClicked", THIS_CLASS);
                if (ChangesToSave)
                {
                    string text = EclipseMessage.GetMessage(AdministrativeFormMessages.SaveChangeBeforeClear).Replace("Failure~","").Replace("Success~","");;
                    DialogResult response = MessageBox.Show(
                        this, 
                        text, 
                        Constants.DataFields.SaveConfirmation,
                        MessageBoxButtons.YesNoCancel,
                        MessageBoxIcon.Exclamation, MessageBoxDefaultButton.Button1);
                    switch (response)
                    {
                        case DialogResult.Yes :
                        {
                            if(!this.SaveAll())
                                return;
                            break;
                        }
                        case DialogResult.Cancel :
                        {
                            this.ddlAgency.Text = this.agency;
                            return;
                        }
                    }
                }
                this._commandLineControl.DisplayMessage(String.Empty);
                if(CadBaseNGPObject.Count>0)
                {
                    this.CadBaseNGPObject=new CADBaseNGPCollection();
					AddNewIfEmpty((CADBaseCollection)this.CadBaseNGPObject);
                    this.RefreshParentDataSource();
                }
                if(!agencyChanged)
                {
                    this.ddlAgency.Text = Wks.MyWks.PriAgency;
                    ddlAgency_Validated(ddlAgency,null);
                }
                RefreshButtons();
                this.cP_HistoryDisplayNGP.ClearHistory();
                this.tabControlNGP.SelectedTab=this.tabPageMain;
                this.gdbgResults.Focus();
                this.ddlNotificationType.Text = String.Empty;
                this.txtNotificationGrpID.Text = String.Empty;
                this.rdMultipleDestination.Checked=true;
                rdDestinationSub_CheckedChanged(null,null);
                this.btnSave.Enabled=false;
                ClearGroupType();
                this.ddlAgency.Focus();
                CADLog.LogDebug("End of Event","cP_FormButtonsNGP_ClearButtonClicked", THIS_CLASS);
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"cP_FormButtonsNGP_ClearButtonClicked", THIS_CLASS);
            }
        }

        /// <summary>
        /// Handler for the Query button click and retrieve the records based on the query criteria
        /// </summary>
        /// <param name="sender">Object</param>
        /// <param name="e">Event Arguments</param>
        private void cP_FormButtonsNGP_InquiryButtonClicked(object sender, EventArgs e)
        {
            Cursor.Current = Cursors.WaitCursor;
            this.tabControlNGP.SelectedTab=this.tabPageMain;
			
            try
            {
                CADLog.LogDebug("Start of Event","cP_FormButtonsNGP_InquiryButtonClicked", THIS_CLASS);
                if (ChangesToSave)
                {
                    string text = EclipseMessage.GetMessage(AdministrativeFormMessages.SaveChanges).Replace("Failure~","").Replace("Success~","");;
                    DialogResult response = MessageBox.Show(
                        this, 
                        text, 
                        Constants.DataFields.SaveConfirmation,
                        MessageBoxButtons.YesNoCancel,
                        MessageBoxIcon.Exclamation, MessageBoxDefaultButton.Button1);
                    switch (response)
                    {
                        case DialogResult.Yes :
                        {
                            if(!this.SaveAll())
                                return;
                            break;
                        }
                        case DialogResult.Cancel :
                        {
                            return;
                        }
                    }
                }
                this.CadBaseNGPObject.ListChanged -= new ListChangedEventHandler(this.ResultsListChanged);
                this.gdbgResults.BindingContext[this.CadBaseNGPObject].PositionChanged -=
                    new EventHandler(this.PositionChanged);
                this.gdbgResults.BeginUpdate();
                CADBaseNGP cbq= new CADBaseNGP();
                cbq.CongrpID=this.txtCongrpid.Text;
                cbq.TypeName=this.ddlNotificationType.Text;
                cbq.GroupId=this.txtNotificationGrpID.Text;
                this.CadBaseNGPObject = (CADBaseNGPCollection) cbq.Query();
                this.RefreshParentDataSource();
                if (this.CadBaseNGPObject.Count == 0)
                {
                    this.gdbgResults.Selections.SelectRange(
                        GridRangeInfo.Rows(this.gdbgResults.Selections.Ranges.ActiveRange.Top,
                        this.gdbgResults.Selections.Ranges.ActiveRange.Bottom), false);
                    this.CadBaseNGPObject.AddNew();
                    this._commandLineControl.DisplayMessage(EclipseMessage.GetMessage(AdministrativeFormMessages.NoRecordsFound));
                }
                else
                {
                    this.DisplayRecord(true);
                    this.gdbgResults.Selections.SelectRange(
                        GridRangeInfo.Rows(this.gdbgResults.Selections.Ranges.ActiveRange.Top,
                        this.gdbgResults.Selections.Ranges.ActiveRange.Bottom), false);
                    this.gdbgResults.Selections.SelectRange(GridRangeInfo.Row(1), true);
                    this.gdbgResults.ScrollCellInView(1,1);
                    this.gdbgResults.Focus();
                    this.gdbgResults.CurrentCell.MoveTo(1,1);
                    this.gdbgResults.CurrentCell.BeginEdit();
                    if (cbq.TableName != null)
                    {
                        this._commandLineControl.DisplayMessage(EclipseMessage.GetMessage(AdministrativeFormMessages.NumRecordsFound) + CadBaseNGPObject.Count.ToString());
                    }
                    else
                    {}
                    this.gdbgResults.Model.ColWidths.ResizeToFit(GridRangeInfo.Table(), GridResizeToFitOptions.IncludeHeaders);
                }
                btnSave.Enabled = false;
                CADLog.LogDebug("End of Event","cP_FormButtonsNGP_InquiryButtonClicked", THIS_CLASS);
            }
            catch (Exception ex)
            {
                CADLog.LogError("Inquiry failed:"+ex.Message, "cP_FormButtonsNGP_InquiryButtonClicked", THIS_CLASS);
            }
            finally
            {
                this.gdbgResults.EndUpdate();
                Cursor.Current = Cursors.Default;
            }
        }
		
        private void txtNumberNotification_KeyDown(object sender, KeyEventArgs e)
        {
            if(e.KeyData==Keys.Subtract || e.KeyData==Keys.OemMinus)
                e.Handled=true;
        }
       
        /// <summary>
        /// Event handler to navigate to the previous or next control 
        /// for Syncfusion grids that have been placed on tab pages.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
		
        private void gdbgResults_WrapCellNextControlInForm(object sender, GridWrapCellNextControlInFormEventArgs e)
        {
            try
            {
                if (e.Forward)
                {
					if(this.grpBoxGroupType.Enabled)
					{
						if(this.rdMultipleDestination.Checked)
							this.rdMultipleDestination.Focus();
						else
							this.rdDestinationSub.Focus();
					}
					else
					{
						if(this.btnSave.Enabled)
							btnSave.Focus();
						else
							this.cP_FormButtonsNGP.Focus();
					}
                }
                else
                    this.tabPageMain.Focus();
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"gdbgResults_WrapCellNextControlInForm", THIS_CLASS);
            }
        }

        /// <summary>
        /// Event handler for the radiobutton destination checked changed, to enable or disable the controls.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void rdDestinationSub_CheckedChanged(object sender, System.EventArgs e)
        {
            try
            {
                CADLog.LogDebug("Start of Event","rdDestinationSub_CheckedChanged", THIS_CLASS);
                if(displayInProgress)
                    return;
                if (rdDestinationSub.Checked == true)
                {
                    EnableGroupType(true);
                    this.CadBaseObject.IsSubstitute="Y";
                }
                else
                {
                    ClearGroupType();
                    EnableGroupType(false);
                    this.CadBaseObject.IsSubstitute="N";
                    this.CadBaseObject.NotificationNumber=null;
                    this.CadBaseObject.NumberExceeds=null;
                    this.CadBaseObject.FromDate=DateTime.MinValue;
                    this.CadBaseObject.ToDate=DateTime.MinValue;
                    this.CadBaseObject.DisplayName=null;
                }
                ProcessLeave();
                CADLog.LogDebug("End of Event","rdDestinationSub_CheckedChanged", THIS_CLASS);
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"rdDestinationSub_CheckedChanged", THIS_CLASS);
            }
        }
        /// <summary>
        /// Event handler to update the status of the business object when the user types a change
        /// into a cell.  We explicitly request the status change because the object does not know
        /// whether the last change was programmatic or user originated - Group Notification grid.
        /// </summary>
        /// <param name="sender">Object</param>
        /// <param name="e">Event Arguments</param>
        private void grdGrpNotification_CurrentCellAcceptedChanges(object sender, CancelEventArgs e)
        {
            try
            {
                CADLog.LogDebug("Start of Event","grdGrpNotification_CurrentCellAcceptedChanges", THIS_CLASS);

                NGSyncfusionGrid gridControl = (NGSyncfusionGrid) sender;

                if(gridControl.CurrentCell.ColIndex==1)
                {
                    gridControl[gridControl.CurrentCell.RowIndex,2].Text=string.Empty;
                    gridControl[gridControl.CurrentCell.RowIndex,3].Text=string.Empty;
                    gridControl[gridControl.CurrentCell.RowIndex,4].Text=string.Empty;
                    gridControl[gridControl.CurrentCell.RowIndex,5].Text=string.Empty;
                    gridControl[gridControl.CurrentCell.RowIndex,6].Text=string.Empty;
					gridControl[gridControl.CurrentCell.RowIndex,7].Text=string.Empty;
					gridControl[gridControl.CurrentCell.RowIndex,8].Text=string.Empty;
                }
                if(gridControl.CurrentCell.ColIndex == 2)
                {
                    if (this.selectedRow != null)
                    {
                        gridControl[gridControl.CurrentCell.RowIndex,3].Text=selectedRow.Row[2].ToString();;
                        gridControl[gridControl.CurrentCell.RowIndex,4].Text=selectedRow.Row[1].ToString();;
                        gridControl[gridControl.CurrentCell.RowIndex,5].Text=selectedRow.Row[3].ToString();;
                        gridControl[gridControl.CurrentCell.RowIndex,6].Text=selectedRow.Row[4].ToString();;
						gridControl[gridControl.CurrentCell.RowIndex,7].Text=selectedRow.Row[5].ToString();
						gridControl[gridControl.CurrentCell.RowIndex,8].Text=selectedRow.Row[6].ToString();
                    }
                    else
                    {
                        string strVal=gridControl.CurrentCell.Renderer.ControlValue.ToString();
                        string[] strsplit=strVal.Split('-');
                        gridControl[gridControl.CurrentCell.RowIndex,3].Text=strsplit[1];
                        gridControl[gridControl.CurrentCell.RowIndex,4].Text=strsplit[0];
                        gridControl[gridControl.CurrentCell.RowIndex,5].Text=strsplit[2];
                        gridControl[gridControl.CurrentCell.RowIndex,6].Text=strsplit[3];
						
						gridControl[gridControl.CurrentCell.RowIndex,7].Text=strsplit[4];
						gridControl[gridControl.CurrentCell.RowIndex,8].Text=strsplit[5];
                    }
                }

                CADBaseNotificationGroup cadBaseObject = (CADBaseNotificationGroup) grdGrpNotification.BindingContext[grdGrpNotification.DataSource].Current;
                cadBaseObject.RecordChanged();
                CadBaseObject.RecordChanged();
                this._commandLineControl.DisplayMessage(String.Empty);

                string colname=grdGrpNotification.GridBoundColumns[grdGrpNotification.CurrentCell.ColIndex-1].MappingName;
                if (!cadBaseObject.IsPropertyValid(colname))
                {
                    this._commandLineControl.DisplayMessage(cadBaseObject.Error, System.Drawing.Color.Red);
                    this.btnSave.Enabled = false;
                    return;
                }
                if ((cadBaseObject.ValidForAdd() && cadBaseObject.RecordStatus == CADBase.RecordStatusFlags.Insert) ||
                    (cadBaseObject.ValidForUpdate() && cadBaseObject.RecordStatus == CADBase.RecordStatusFlags.Changed))
                    btnSave.Enabled = true;
                else
                    btnSave.Enabled = false;
                CADLog.LogDebug("End of Event","grdGrpNotification_CurrentCellAcceptedChanges", THIS_CLASS);
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"grdGrpNotification_CurrentCellAcceptedChanges", THIS_CLASS);
                e.Cancel = true;
                this.btnSave.Enabled = false;
            }
        }
        /// <summary>
        /// Event handler to update the status of the business object when the user types a change
        /// into a cell.  We explicitly request the status change because the object does not know
        /// whether the last change was programmatic or user originated - Results grid.
        /// </summary>
        /// <param name="sender">Object</param>
        /// <param name="e">Event Arguments</param>
        private void gdbgResults_CurrentCellAcceptedChanges(object sender, System.ComponentModel.CancelEventArgs e)
        {
            try
            {
                CADLog.LogDebug("Start of Event","gdbgResults_CurrentCellAcceptedChanges", THIS_CLASS);
                CADBaseNGP cadBaseObject = (CADBaseNGP) gdbgResults.BindingContext[gdbgResults.DataSource].Current;
                cadBaseObject.RecordChanged();
                CadBaseObject.RecordChanged();

			
                this._commandLineControl.DisplayMessage(String.Empty);

                string colname=gdbgResults.GridBoundColumns[gdbgResults.CurrentCell.ColIndex-1].MappingName;
                if (!cadBaseObject.IsPropertyValid(colname))
                {
                    this._commandLineControl.DisplayMessage(cadBaseObject.Error, System.Drawing.Color.Red);
                    this.btnSave.Enabled = false;
                    return;
                }

                if ((cadBaseObject.ValidForAdd() && cadBaseObject.RecordStatus == CADBase.RecordStatusFlags.Insert) ||
                    (cadBaseObject.ValidForUpdate() && cadBaseObject.RecordStatus == CADBase.RecordStatusFlags.Changed))
                    btnSave.Enabled = true;
                else
                    btnSave.Enabled = false;

                NGSyncfusionGrid gridControl = (NGSyncfusionGrid) sender;
                if(gridControl.CurrentCell.ColIndex==1 && this.rdDestinationSub.Checked )
                {
                    this.cbService.Text=String.Empty;
                    this.CadBaseObject.DisplayName=String.Empty;
                }
                CADLog.LogDebug("End of Event","gdbgResults_CurrentCellAcceptedChanges", THIS_CLASS);

            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"gdbgResults_CurrentCellAcceptedChanges", THIS_CLASS);
                e.Cancel = true;
                this.btnSave.Enabled = false;
            }
        }
        /// <summary>
        /// When a cell activates
        /// If it is a dropdown list, update the shared grid list control with the correct values of the results grid.
        /// </summary>
        /// <param name="sender">Object</param>
        /// <param name="e">Event Arguements</param>
        private void gdbgResults_CurrentCellActivated(object sender, System.EventArgs e)
        {
            try
            {
                CADLog.LogDebug("Start of Event","gdbgResults_CurrentCellActivated", THIS_CLASS);
                ConfigureResultsDropDowns((NGSyncfusionGrid)sender);
                CADLog.LogDebug("End of Event","gdbgResults_CurrentCellActivated", THIS_CLASS);
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"gdbgResults_CurrentCellActivated", THIS_CLASS);
            }
        }

        /// <summary>
        /// Event handler for grid row enter events to enable or disable the delete button.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void gdbgResults_RowEnter(object sender, GridRowEventArgs e)
        {
            try
            {
                if (e.RowIndex < 1 || e.RowIndex > this.CadBaseNGPObject.Count + 1)
                    return;

                if (this.CadBaseNGPObject.Count > 0)
                {
                    if (e.RowIndex == CadBaseNGPObject.Count + 1)
                    {
                        cP_FormButtonsNGP.DeleteButtonVisible = true;
                        cP_FormButtonsNGP.DeleteButtonEnabled = false;
                        return;
                    }
                    else
                    {
                        cP_FormButtonsNGP.DeleteButtonVisible = true;
                        cP_FormButtonsNGP.DeleteButtonEnabled = true;
                    }
                }
            }
            catch (Exception ex)
            {
                CADLog.LogError("Exception in RowEnter: " + ex.Message, "gdbgResults_RowEnter", THIS_CLASS);
            }
        }
        /// <summary>
        /// When a cell activates
        /// If it is a dropdown list, update the shared grid list control with the correct values of the Group Notification grid.
        /// </summary>
        /// <param name="sender">Object</param>
        /// <param name="e">Event Arguements</param>
        private void grdGrpNotification_CurrentCellActivated(object sender, EventArgs e)
        {
            try
            {
                CADLog.LogDebug("Start of Event","grdGrpNotification_CurrentCellActivated", THIS_CLASS);
                ConfigureNotificationDropDowns((NGSyncfusionGrid)sender);

                CADLog.LogDebug("End of Event","grdGrpNotification_CurrentCellActivated", THIS_CLASS);
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"grdGrpNotification_CurrentCellActivated", THIS_CLASS);
            }
        }

        /// <summary>
        /// Handler for Group Notification current cell show and display the all the combo's.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void grdGrpNotification_CurrentCellShowingDropDown(object sender, GridCurrentCellShowingDropDownEventArgs e)
        {
            try
            {
                CADLog.LogDebug("Start of Event","grdGrpNotification_CurrentCellShowingDropDown", THIS_CLASS);
                ConfigureNotificationDropDowns((NGSyncfusionGrid)sender);
                CADLog.LogDebug("End of Event","grdGrpNotification_CurrentCellShowingDropDown", THIS_CLASS);
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"grdGrpNotification_CurrentCellShowingDropDown", THIS_CLASS);
            }
        }
        /// <summary>
        /// Populate the appropriate drop down list for the current column in the Results grid.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void gdbgResults_CurrentCellShowingDropDown(object sender, GridCurrentCellShowingDropDownEventArgs e)
        {
            try
            {
                CADLog.LogDebug("Start of Event","gdbgResults_CurrentCellShowingDropDown", THIS_CLASS);
                ConfigureResultsDropDowns((NGSyncfusionGrid)sender);
                CADLog.LogDebug("End of Event","gdbgResults_CurrentCellShowingDropDown", THIS_CLASS);
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"gdbgResults_CurrentCellShowingDropDown", THIS_CLASS);
            }
        }
        /// <summary>
        /// Handler for Home, End, Copy, Paste operation.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void gdbgResults_CurrentCellControlKeyMessage(
            object sender, 
            GridCurrentCellControlKeyMessageEventArgs e)
        {
            try
            {
                CADLog.LogDebug("Start of Event","gdbgResults_CurrentCellControlKeyMessage", THIS_CLASS);
                Keys keyCode = (Keys)((int)e.Msg.WParam) & Keys.KeyCode;
                if((Control.ModifierKeys & Keys.Control) != 0)
                {
                    if(keyCode == Keys.Home || keyCode == Keys.End)
                    {
                        //// CONTROL + HOME or CONTROL + END
                        e.Handled = false;
                        e.Result = false;
                    }
                    if (keyCode == Keys.C)
                    {
                        this.gdbgResults.CurrentCell.Renderer.Copy();
                        e.Handled=true;
                        e.Result = true;
                    }
                    if (keyCode == Keys.X)
                    {
                        this.gdbgResults.CurrentCell.Renderer.Copy();
                        this.gdbgResults.CurrentCell.Renderer.ControlValue=String.Empty;
                        e.Handled=true;
                        e.Result = true;
                    }
                }
                else
                {
                    if(keyCode == Keys.Home)
                    {
                        this.gdbgResults.CurrentCell.MoveTo(this.gdbgResults.CurrentCell.RowIndex, 1);
                        this.gdbgResults.ScrollCellInView(this.gdbgResults.CurrentCell.RowIndex, 1);
                        //// HOME
                        e.Handled = true;
                        e.Result = true;
                    }
                    if (keyCode == Keys.End)
                    {
                        this.gdbgResults.CurrentCell.MoveTo(
                            this.gdbgResults.CurrentCell.RowIndex, this.gdbgResults.GridBoundColumns.Count);
                        this.gdbgResults.ScrollCellInView(
                            this.gdbgResults.CurrentCell.RowIndex, 
                            this.gdbgResults.GridBoundColumns.Count);
                        //// END
                        e.Handled = true;
                        e.Result = true;
                    }
                }
                CADLog.LogDebug("End of Event","gdbgResults_CurrentCellControlKeyMessage", THIS_CLASS);
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"gdbgResults_CurrentCellControlKeyMessage", THIS_CLASS);
            }
        }

        /// <summary>
        /// Handler if the tab key is pressed
        /// </summary>
        /// <param name="sender">Object</param>
        /// <param name="e">Event Arguements</param>
        private void gdbgResults_CurrentCellKeyPress(object sender, KeyPressEventArgs e)
        {
            try
            {
                CADLog.LogDebug("Start of Event","gdbgResults_CurrentCellKeyPress", THIS_CLASS);
                if(e.KeyChar=='\t')
                    e.Handled=true;
                CADLog.LogDebug("End of Event","gdbgResults_CurrentCellKeyPress", THIS_CLASS);
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"gdbgResults_CurrentCellKeyPress", THIS_CLASS);
            }
        }
        /// <summary>
        /// Event Handler for validating the Notification grid Current cell.
        /// </summary>
        /// <param name="sender">Object</param>
        /// <param name="e">Event Arguements</param>
        private void grdGrpNotification_CurrentCellValidating(object sender, CancelEventArgs e)
        {
            try
            {
                CADLog.LogDebug("Start of Event","grdGrpNotification_CurrentCellValidating", THIS_CLASS);
                this.grdGrpNotification.Model.ColWidths.ResizeToFit(GridRangeInfo.Table(), GridResizeToFitOptions.IncludeHeaders);
                this._commandLineControl.DisplayMessage(String.Empty);
                RefreshButtons();
                CADLog.LogDebug("End of Event","grdGrpNotification_CurrentCellValidating", THIS_CLASS);
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"grdGrpNotification_CurrentCellValidating", THIS_CLASS);
            }
        }

        /// <summary>
        /// Handler for validating Results grid current cell.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void gdbgResults_CurrentCellValidating(object sender, CancelEventArgs e)
        {
            try
            {
                CADLog.LogDebug("Start of Event","gdbgResults_CurrentCellValidating", THIS_CLASS);
                this.gdbgResults.Model.ColWidths.ResizeToFit(
                    GridRangeInfo.Table(), GridResizeToFitOptions.IncludeHeaders);
                this._commandLineControl.DisplayMessage(String.Empty);
                RefreshButtons();
                CADLog.LogDebug("End of Event","gdbgResults_CurrentCellValidating", THIS_CLASS);
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"gdbgResults_CurrentCellValidating", THIS_CLASS);
            }
        }
        /// <summary>
        /// Event handler for grid row leave events.  Validate the record and prevent the user from 
        /// leaving the record if any errors are found.
        /// </summary>
        /// <param name="sender">Object</param>
        /// <param name="e">Event Arguments</param>
        private void gdbgResults_RowLeave(object sender, GridRowEventArgs e)
        {
            try
            {
                CADLog.LogDebug("Start of Event","gdbgResults_RowLeave", THIS_CLASS);
                if (!this.RowLeave((GridDataBoundGrid)sender))
                {
                    GridDataBoundGrid gridControl = (GridDataBoundGrid)sender;
                    CADBase cadBaseObject = (CADBase) gridControl.
                        BindingContext[gridControl.DataSource].Current;
                    this._commandLineControl.
                        DisplayMessage(cadBaseObject.Error, Color.Red);

                    e.Cancel = true;
                }
                CADLog.LogDebug("End of Event","gdbgResults_RowLeave", THIS_CLASS);
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"gdbgResults_RowLeave", THIS_CLASS);
            }
        }
        /// <summary>
        /// This method is used to set the notification number and refresh button.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void txtNotificationID_Leave(object sender, System.EventArgs e)
        {
            try
            {
                CADLog.LogDebug("Start of Event","txtNotificationID_Leave", THIS_CLASS);
                this.CadBaseObject.NotificationNumber=txtNotificationID.Text;
                this.ClearError(txtNotificationID);
                CADLog.LogDebug("End of Event","txtNotificationID_Leave", THIS_CLASS);
            }
            catch(Exception ex)
            {
                this.ShowError(txtNotificationID, ex);
                CADLog.LogError(ex.ToString(),"txtNotificationID_Leave", THIS_CLASS);
            }
            finally
            {
                ProcessLeave();
            }

        }

        /// <summary>
        /// This method is used to set the service and refresh button
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void cbService_Leave(object sender, System.EventArgs e)
        {
            try
            {
                CADLog.LogDebug("Start of Event","cbService_Leave", THIS_CLASS);
                this.CadBaseObject.DisplayName=cbService.Text;
                this.ClearError(cbService);
                CADLog.LogDebug("Start of Event","cbService_Leave", THIS_CLASS);
            }
            catch(Exception ex)
            {
                this.ShowError(cbService, ex);
                CADLog.LogError(ex.ToString(),"cbService_Leave", THIS_CLASS);
            }
            finally
            {
                ProcessLeave();
            }

        }

        /// <summary>
        /// Is used to set the From date in the Cadbase object and refresh button
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void dtFromDate_Leave(object sender, System.EventArgs e)
        {
            try
            {
                CADLog.LogDebug("Start of Event","dtFromDate_Leave", THIS_CLASS);
                if(dtFromDate.Value.TimeOfDay.Ticks>0)
                {
                    this.CadBaseObject.FromDate=DateTime.Today.Date.AddTicks(dtFromDate.Value.TimeOfDay.Ticks);
                    //					this.CadBaseObject.NumberExceeds="";
                    //					this.txtNumberNotification.Text="";
                    this.ClearError(dtFromDate);
                }
                CADLog.LogDebug("End of Event","dtFromDate_Leave", THIS_CLASS);
            }
            catch(Exception ex)
            {
                this.ShowError(dtFromDate, ex);
                CADLog.LogError(ex.ToString(),"dtFromDate_Leave", THIS_CLASS);
            }
            finally
            {
                ProcessLeave();
            }
        }

        /// <summary>
        /// Handler for Save button click to save the record.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnSave_Click(object sender, System.EventArgs e)
        {
            try
            {
                CADLog.LogDebug("Start of Event","btnSave_Click", THIS_CLASS);
                this.SaveAll();
                CADLog.LogDebug("End of Event","btnSave_Click", THIS_CLASS);
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"btnSave_Click", THIS_CLASS);
            }
        }

        /// <summary>
        /// Update the currentGridControl variable when we enter a grid.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void gridDataBoundGrid_Enter(object sender, System.EventArgs e)
        {
            try
            {
                CADLog.LogDebug("Start of Event","gridDataBoundGrid_Enter", THIS_CLASS);
                NGSyncfusionGrid currentGridControl = (NGSyncfusionGrid) sender;
                if (currentGridControl == null)
                    return;
				
                CADLog.LogDebug("End of Event","gridDataBoundGrid_Enter", THIS_CLASS);

            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"gridDataBoundGrid_Enter", THIS_CLASS);
            }
	
        }
        private void cbService_Enter(object sender, EventArgs e)
        {
            try
            {
                CADLog.LogDebug("Start of Event","cbService_Enter", THIS_CLASS);
                string where = String.Empty;
                where = "TypeName = '" + this.CadBaseObject.TypeName +"'";
                NRSNotificationServiceValidator ddcNotificationService = new NRSNotificationServiceValidator(where);
                this.cbService.AutoCompleteControl.DataSource = ddcNotificationService.GetDataView();
                this.cbService.AutoCompleteControl.ShowColumnHeader = true;
                CADLog.LogDebug("End of Event","cbService_Enter", THIS_CLASS);
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"cbService_Enter", THIS_CLASS);
            }
        }


        /// <summary>
        /// Call to a common routine to print selected rows in the Grid
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e">Event Args holds detail about the menu option selection from Output Menu </param>
        private void cP_FormButtonsNGP_OutputButtonClicked(object sender, OutputEventArgs e)
        {
            try
            {
                CADLog.LogDebug("Start of Event","cP_FormButtonsNGP_OutputButtonClicked", THIS_CLASS);
                if(this.CadBaseObject==null)
                    return;
                CADBase cadBaseObject = (CADBase) gdbgResults.BindingContext[gdbgResults.DataSource].Current;
                BaseFormHandler.PrintSelectedRows(this.gdbgResults, typeof(CADBaseNGP), e);
                CADLog.LogDebug("End of Event","cP_FormButtonsNGP_OutputButtonClicked", THIS_CLASS);
            }
            catch(EclipseException ex)
            {			
                this._commandLineControl.DisplayMessage(EclipseMessage.GetMessage(AdministrativeFormMessages.PrintException), Color.Red);
                CADLog.LogError(ex.Message,"cP_FormButtonsNGP_OutputButtonClicked", THIS_CLASS);
            }
            catch(Exception ex)
            {
                this._commandLineControl.DisplayMessage(ex.Message, Color.Red);
                CADLog.LogError(ex.Message,"cP_FormButtonsNGP_OutputButtonClicked", THIS_CLASS);
            }
        }
		

        /// <summary>
        /// Event handler for the form closing event to check for unsaved changes and warn the user.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void FormNGP_Closing(object sender, CancelEventArgs e)
        {
            try
            {
                CADLog.LogDebug("Start of Event","FormNGP_Closing", THIS_CLASS);
                if (ChangesToSave)
                {
                    string text = EclipseMessage.GetMessage(AdministrativeFormMessages.SaveChanges).Replace("Failure~","").Replace("Success~","");;
                    DialogResult response = MessageBox.Show(
                        this, 
                        text, 
                        Constants.DataFields.SaveConfirmation,
                        MessageBoxButtons.YesNoCancel,
                        MessageBoxIcon.Exclamation, MessageBoxDefaultButton.Button1);
                    switch (response)
                    {
                        case DialogResult.Yes :
                        {
                            if(!this.SaveAll())
                                e.Cancel=true;
                            break;
                        }
                        case DialogResult.Cancel :
                        {
                            e.Cancel = true;
                            break;
                        }
                    }
                }
                CADLog.LogDebug("End of Event","FormNGP_Closing", THIS_CLASS);
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"FormNGP_Closing", THIS_CLASS);
            }
        }
        #endregion

        #region Private Methods
        /// <summary>
        /// This method is retrieve the substituteNotif DOS Option
        /// </summary>
        private string GetSubstitutionDOS()
        {
            try
            {
                CADLog.LogDebug("Start of Method","GetSubstitutionDOS", THIS_CLASS);
                IDOSParameter emdDOS = (IDOSParameter)FM.FManager.GetFactory (new string[]{Wks.MyWks.PriAgency,"SubstituteNotif"},Shared.CADEnum.FactoryInterfaces.IDOSParameter );
                if (emdDOS != null)
                    return emdDOS.BoolFlag;
                CADLog.LogDebug("End of Method","GetSubstitutionDOS", THIS_CLASS);
                return string.Empty;
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"GetSubstitutionDOS", THIS_CLASS);
                return string.Empty;
            }
        }
        /// <summary>
        /// This method is used to set agency, datagroup, agencies in data group.
        /// </summary>
        private void AgencySetUp()
        {
            try
            {
                CADLog.LogDebug("Start of Method","AgencySetUp", THIS_CLASS);
                string congrpid = FM.FManager.fmGetDataGroupForAgc (this.ddlAgency.Text,"NRS");
                this.txtCongrpid.Text = congrpid;
                DataGroupValidator dataGroupVal = new DataGroupValidator();
                agenciesInCongrpid = dataGroupVal.GetCongrpidAgencies(congrpid, "NRS");
                StringBuilder agencyList= new StringBuilder();
                foreach (string str in agenciesInCongrpid)
                {
                    agencyList.Append((agencyList.ToString() == String.Empty ? String.Empty : ", ") + str);
                }
                this.txtAgenciesInCongrpid.Text = agencyList.ToString();
                CADLog.LogDebug("End of Method","AgencySetUp", THIS_CLASS);
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"AgencySetUp", THIS_CLASS);
            }
        }
        /// <summary>
        /// This method is used to configure the Group Notification, results grid.
        /// </summary>
        private void ConfigureGrids()
        {			
            try
            {
                CADLog.LogDebug("Start of Method","ConfigureGrids", THIS_CLASS);
                this.gdbgResults.Binder.DirectSaveCellInfo = true;
                this.gdbgResults.Model.Options.WrapCellBehavior = GridWrapCellBehavior.NextControlInForm;
                this.gdbgResults.WantTabKey = true;
                this.gdbgResults.ActivateCurrentCellBehavior = GridCellActivateAction.SelectAll;

                this.grdGrpNotification.Binder.DirectSaveCellInfo = true;
                this.grdGrpNotification.Model.Options.WrapCellBehavior = GridWrapCellBehavior.NextControlInForm;
                this.grdGrpNotification.WantTabKey = true;
                this.grdGrpNotification.ActivateCurrentCellBehavior = GridCellActivateAction.SelectAll;
                this.grdGrpNotification.Model.Cols.Hidden[3]=true;
                this.grdGrpNotification.Model.Cols.Hidden[4]=true;
                this.grdGrpNotification.Model.Cols.Hidden[5]=true;
                this.grdGrpNotification.Model.Cols.Hidden[6]=true;
				this.grdGrpNotification.Model.Cols.Hidden[7]=true;
				this.grdGrpNotification.Model.Cols.Hidden[8]=true;
                CADLog.LogDebug("End of Method","ConfigureGrids", THIS_CLASS);

            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"ConfigureGrids", THIS_CLASS);
            }
        }

        /// <summary>
        /// This method is used to Load the Comboboxes.
        /// </summary>
        private void LoadComboBoxes()
        {
            try
            {
                CADLog.LogDebug("Start of Method","LoadComboBoxes", THIS_CLASS);
                BaseFormHandler.LoadAutoCompleteAgency(String.Empty, commandLineParameters.CadCommandInfo.InCommand, this.ddlAgency);
                this.ddlAgency.DisplayMember = "Agency";
                this.ddlAgency.ValueMember = "Agency";
                this.agency = this.ddlAgency.Text = Wks.MyWks.PriAgency;
                this.ddlAgency_Validated(ddlAgency,null);
			
                this.rdMultipleDestination.Checked=true;
                this.ddlNotificationType.AutoCompleteControl.DataSource = dvNotificationType.GetDataView();

                NRSNotificationServiceValidator ddcNotificationService = new NRSNotificationServiceValidator(String.Empty);
                this.cbService.AutoCompleteControl.DataSource = ddcNotificationService.GetDataView();
                this.cbService.AutoCompleteControl.ShowColumnHeader = true;
                CADLog.LogDebug("End of Method","LoadComboBoxes", THIS_CLASS);
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"LoadComboBoxes", THIS_CLASS);
            }
        }

        /// <summary>
        /// This method is used to refresh the buttons based on the cadbase object.
        /// </summary>
        private void RefreshButtons()
        {
            try
            {
                CADLog.LogDebug("Start of Method","RefreshButtons", THIS_CLASS);
                this.cP_FormButtonsNGP.RefreshButtons(this.CadBaseObject);
                if (this.CadBaseNGPObject==null || this.CadBaseNGPObject.Count==0)
                    this.grpBoxGroupType.Enabled=false;
                else
                    this.grpBoxGroupType.Enabled=true;

                CADLog.LogDebug("End of Method","RefreshButtons", THIS_CLASS);
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"RefreshButtons", THIS_CLASS);
            }
        }
        /// <summary>
        /// This method is used to refresh parent data source.
        /// </summary>
        private void RefreshParentDataSource()
        {
            try
            {
                CADLog.LogDebug("Start of Method","RefreshParentDataSource", THIS_CLASS);
                this.gdbgResults.DataSource = null;
                this.gdbgResults.DataSource = this.CadBaseNGPObject;
                this.grdGrpNotification.DataSource=null;
                if(this.CadBaseObject!=null)
                    this.grdGrpNotification.DataSource = this.CadBaseObject.NotificationGroupList;
                this.CadBaseNGPObject.ListChanged += new ListChangedEventHandler(this.ResultsListChanged);
                this.gdbgResults.BindingContext[this.CadBaseNGPObject].PositionChanged +=
                    new EventHandler(this.PositionChanged);
                CADLog.LogDebug("End of Method","RefreshParentDataSource", THIS_CLASS);
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"RefreshParentDataSource", THIS_CLASS);
            }
        }
		
        /// <summary>
        /// Method is used to add new collection if it is empty.
        /// </summary>
        /// <param name="collection">CADBaseCollection</param>
        private void AddNewIfEmpty(CADBaseCollection collection)
        {
            try
            {
                CADLog.LogDebug("Start of Method","AddNewIfEmpty", THIS_CLASS);
                if (collection.Count == 0)
                    collection.AddNew();
                CADLog.LogDebug("End of Method","AddNewIfEmpty", THIS_CLASS);
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"AddNewIfEmpty", THIS_CLASS);
            }
        }
		
        /// <summary>
        /// This method is used to display Notification Record.
        /// </summary>
        /// <param name="display">bool</param>
        private void DisplayRecord(bool display)
        {
            try
            {
                CADLog.LogDebug("Start of Method","DisplayRecord", THIS_CLASS);
                displayInProgress=true;
                if(display)
                {
                    if (this.CadBaseObject.ValidForDisplay())
                        CadBaseObject.Display();
                }
                ClearGroupType();
                if(grpBoxGroupType.Visible)
                {
                    if(CadBaseObject.IsSubstitute=="Y" )
                    {
                        EnableGroupType(true);
                        this.rdDestinationSub.Checked=true;
                        this.txtNotificationID.Text=CadBaseObject.NotificationNumber;
                        if(CadBaseObject.NumberExceeds!="-1")
                            this.txtNumberNotification.Text=CadBaseObject.NumberExceeds;
                        this.cbService.Text=CadBaseObject.DisplayName;
                        if (this.CadBaseObject.FromDate == DateTime.MinValue)
                        {
                            this.dtFromDate.Checked = false;
                        }
                        else
                        {
                            this.dtFromDate.Value=CadBaseObject.FromDate;
                        }
                        if (this.CadBaseObject.ToDate == DateTime.MinValue)
                        {
                            this.dtToDate.Checked = false;
                        }
                        else
                        {
                            this.dtToDate.Value = CadBaseObject.ToDate;
                        }
                    }
                    else
                    {
                        EnableGroupType(false);
                        this.rdMultipleDestination.Checked=true;
                    }
                }
                this.grdGrpNotification.DataSource=null;
                this.grdGrpNotification.DataSource=this.CadBaseObject.NotificationGroupList;
                this.grdGrpNotification.Model.ColWidths.ResizeToFit(GridRangeInfo.Table(), GridResizeToFitOptions.IncludeHeaders);
                this.cP_HistoryDisplayNGP.DisplayHistory(CadBaseObject);
                this.RefreshButtons();
                displayInProgress=false;
                CADLog.LogDebug("End of Method","DisplayRecord", THIS_CLASS);
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"DisplayRecord", THIS_CLASS);
            }
        }

        /// <summary>
        /// Process command keys handler
        /// </summary>
        /// <param name="msg">Message</param>
        /// <param name="keyData">Keydata</param>
        /// <returns>bool</returns>
        protected override bool ProcessCmdKey( ref Message msg, Keys keyData )
        {        
            try
            {
                CADLog.LogDebug("Start of Method","ProcessCmdKey", THIS_CLASS);
                bool bHandled = false;
                switch (keyData)
                {                 
                    case Keys.Alt|Keys.D:
                        if(this.cP_FormButtonsNGP.DeleteButtonEnabled)
                            this.cP_FormButtonsNGP_DeleteButtonClicked(null,null);
                        bHandled = true;
                        break;
                    case Keys.Alt|Keys.P:
                        if(this.cP_FormButtonsNGP.OutputButtonEnabled)
                            this.cP_FormButtonsNGP_OutputButtonClicked(null,null);
                        bHandled = true;
                        break;
					// SIRT 30104 START
					case Keys.Alt|Keys.Y:
						this.tabControlNGP.SelectedTab = tabPageMain;
						if (this.gdbgResults.CurrentCell.RowIndex > 0)
							this.gdbgResults.SetFocusToCell(gdbgResults.CurrentCell.RowIndex,1);
						else
							this.gdbgResults.SetFocusToCell(1,1);
						bHandled = true;
						break;
					case Keys.Alt|Keys.R:
						this.tabControlNGP.SelectedTab = tabPageMain;
						if (this.gdbgResults.CurrentCell.RowIndex > 0)
							this.gdbgResults.SetFocusToCell(gdbgResults.CurrentCell.RowIndex,2);
						else
							this.gdbgResults.SetFocusToCell(1, 2);
						bHandled = true;
						break;
					case Keys.Alt|Keys.C:
						this.tabControlNGP.SelectedTab = tabPageNotification;
						if (this.grdGrpNotification.CurrentCell.RowIndex > 0)
							this.grdGrpNotification.SetFocusToCell(grdGrpNotification.CurrentCell.RowIndex,1);
						else
							this.grdGrpNotification.SetFocusToCell(1,1);
						bHandled = true;
						break;
					case Keys.Alt|Keys.B:
						this.tabControlNGP.SelectedTab = tabPageNotification;
						if (this.grdGrpNotification.CurrentCell.RowIndex > 0)
							this.grdGrpNotification.SetFocusToCell(grdGrpNotification.CurrentCell.RowIndex,2);
						else
							this.grdGrpNotification.SetFocusToCell(1,2);
						bHandled = true;
						break;
					// SIRT 30104 END
                    default:
                        bHandled = base.ProcessCmdKey(ref msg, keyData);
                        break;
                }
                CADLog.LogDebug("End of Method","ProcessCmdKey", THIS_CLASS);
                return bHandled;
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"ProcessCmdKey", THIS_CLASS);
                return false;
            }
        }

        /// <summary>
        /// Save any outstanding changes.
        /// </summary>
        private bool SaveAll()
        {
            string responseMessage = String.Empty;
            int recordsUpdated = 0;
            int recordsAdded = 0;
            try
            {
                CADLog.LogDebug("Start of Method","SaveAll", THIS_CLASS);
                foreach (CADBaseNGP objNGP in CadBaseNGPObject)
                {
                    if (objNGP.RecordStatus == CADBase.RecordStatusFlags.New || 
                        objNGP.RecordStatus == CADBase.RecordStatusFlags.Insert)
                    {
                        objNGP.Agency=this.ddlAgency.Text;
                        objNGP.Add();
                        recordsAdded++;
                    }
                    else if (objNGP.RecordStatus == CADBase.RecordStatusFlags.Changed)
                    {
                        objNGP.Update();
                        recordsUpdated++;
                    }
                }
                if ( recordsAdded > 0 )
                    responseMessage += (responseMessage.Length > 0 ? "  " : String.Empty) + recordsAdded.ToString() + " record" + (recordsAdded > 1 ? "s" : String.Empty) + " added.";
                if ( recordsUpdated > 0 )
                    responseMessage += (responseMessage.Length > 0 ? "  " : String.Empty) + recordsUpdated.ToString() + " record" + (recordsUpdated > 1 ? "s" : String.Empty) + " updated.";
                if ( recordsAdded==0 && recordsUpdated == 0 )
                    responseMessage = EclipseMessage.GetMessage(AdministrativeFormMessages.NoChanges);
                this._commandLineControl.DisplayMessage(responseMessage);
                btnSave.Enabled = false;
                CADLog.LogDebug("End of Method","SaveAll", THIS_CLASS);
                return true;
            }
            catch (ValidatorException ex)
            {
                CADLog.LogError(AdministrativeFormMessages.SaveAllFailed + " : "+ ex.Message + ex.StackTrace, "SaveAll", THIS_CLASS);
                this._commandLineControl.DisplayMessage(EclipseMessage.GetMessage(AdministrativeFormMessages.SaveAllFailed) + " : "+ ex.Message +" "+ex._FieldName,System.Drawing.Color.Red);
                return false;
            }
            catch (Exception ex)
            {
                CADLog.LogError(AdministrativeFormMessages.SaveAllFailed + " : "+ ex.Message + ex.StackTrace, "SaveAll", THIS_CLASS);
                this._commandLineControl.DisplayMessage(EclipseMessage.GetMessage(AdministrativeFormMessages.SaveAllFailed) + " : "+ ex.Message,System.Drawing.Color.Red);
                return false;
            }		
        }
		
        /// <summary>
        /// This method is used to check the object is valid when row leaves
        /// </summary>
        /// <param name="sender">Grid object</param>
        /// <returns>bool</returns>
        private bool RowLeave(GridDataBoundGrid sender)
        {
            try
            {
                CADLog.LogDebug("Start of Method","RowLeave", THIS_CLASS);
                GridDataBoundGrid gridControl = sender;
                gridControl.Model.ColWidths.ResizeToFit(
                    GridRangeInfo.Table(), GridResizeToFitOptions.IncludeHeaders);
                CADBase cadBaseObject = (CADBase) gridControl.BindingContext[gridControl.DataSource].Current;
                if (cadBaseObject.RecordStatus == CADBase.RecordStatusFlags.Changed ||
                    cadBaseObject.RecordStatus == CADBase.RecordStatusFlags.New ||
                    cadBaseObject.RecordStatus == CADBase.RecordStatusFlags.Insert)
                {
                    bool isvalid=cadBaseObject.IsValid();
                    if (CadBaseObject.IsValid())
                    {
                        if(!isvalid)
                        {
                            this.btnSave.Enabled = false;
                            return false;
                        }
                        else
                        {
                            this.btnSave.Enabled = true;
                            this._commandLineControl.DisplayMessage(String.Empty);
                        }
                    }
                    else
                    {
                        this.btnSave.Enabled = false;
                        return false;
                    }
                }
                CADLog.LogDebug("End of Method","RowLeave", THIS_CLASS);
                return true;
				
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"RowLeave", THIS_CLASS);
                return true;
            }
        }

        /// <summary>
        /// This method is used to show the error in the commandline and refresh button.
        /// </summary>
        /// <param name="obj">Control</param>
        /// <param name="ex">Exception</param>
        private void ShowError(Control obj, Exception ex) 
        {
            try
            {
                CADLog.LogDebug("Start of Method","ShowError", THIS_CLASS);
                this._commandLineControl.DisplayMessage(ex.Message, Color.Red);
                errorProvider.SetError (obj,ex.Message);
                this.RefreshButtons();
                CADLog.LogDebug("End of Method","ShowError", THIS_CLASS);
            }
            catch (Exception e)
            {
                CADLog.LogError(e.ToString(),"ShowError", THIS_CLASS);
            }
        }
        /// <summary>
        /// This method is used to clear the error in the commandline and refresh button.
        /// </summary>
        /// <param name="obj">Control</param>
        private void ClearError(Control obj) 
        {
            try
            {
                CADLog.LogDebug("Start of Method","ClearError", THIS_CLASS);
                errorProvider.SetError (obj,String.Empty);
                this._commandLineControl.DisplayMessage(String.Empty);
                this.RefreshButtons();
                CADLog.LogDebug("End of Method","ClearError", THIS_CLASS);
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"ClearError", THIS_CLASS);
            }
        }

        /// <summary>
        /// This method is used to clear the Group Type GroupBox Controls
        /// </summary>
        private void ClearGroupType()
        {
            try
            {
                CADLog.LogDebug("Start of Method","ClearGroupType", THIS_CLASS);
                this.ClearError(txtNotificationID);
                this.txtNotificationID.Text=String.Empty;
                this.ClearError(txtNumberNotification);
                this.txtNumberNotification.Text=String.Empty;
                this.ClearError(cbService);
                this.cbService.SelectedIndex=-1;
                this.cbService.Text=String.Empty;
                this.ClearError(dtFromDate);
                this.dtFromDate.Value=DateTime.MinValue;
                this.ClearError(dtToDate);
                this.dtToDate.Value = DateTime.MinValue;
                dtFromDate.NullString="";
                dtToDate.NullString="";
                dtFromDate.IsNullDate=true;
                dtToDate.IsNullDate=true;
                CADLog.LogDebug("End of Method","ClearGroupType", THIS_CLASS);
            }
            catch (Exception e)
            {
                CADLog.LogError(e.ToString(),"ClearGroupType", THIS_CLASS);
            }
        }
        /// <summary>
        /// This method is used to enable or disable the Group Type GroupBox Controls
        /// </summary>
        private void EnableGroupType(bool enabled)
        {
            try
            {
                CADLog.LogDebug("Start of Method","EnableGroupType", THIS_CLASS);
                this.txtNotificationID.Enabled = enabled;
                this.cbService.Enabled = enabled;
                this.dtFromDate.Enabled = enabled;
                dtFromDate.IsNullDate=!enabled;
                this.dtToDate.Enabled=enabled;
                dtToDate.IsNullDate=!enabled;
                this.txtNumberNotification.Enabled = enabled;
                CADLog.LogDebug("End of Method","EnableGroupType", THIS_CLASS);
            }
            catch (Exception e)
            {
                CADLog.LogError(e.ToString(),"EnableGroupType", THIS_CLASS);
            }
        }
        /// <summary>
        /// This method is used to enable the save based on the status of the cadbase object.
        /// </summary>
        private void ProcessLeave()
        {
            try
            {
                CADLog.LogDebug("Start of Method","ProcessLeave", THIS_CLASS);
                this.CadBaseObject.RecordChanged();
                this.RefreshButtons();
                if ((CadBaseObject.ValidForAdd() && CadBaseObject.RecordStatus == CADBase.RecordStatusFlags.Insert) ||
                    (CadBaseObject.ValidForUpdate() && CadBaseObject.RecordStatus == CADBase.RecordStatusFlags.Changed))
                    btnSave.Enabled = true;
                else
                    btnSave.Enabled = false;
                CADLog.LogDebug("End of Method","ProcessLeave", THIS_CLASS);
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"ProcessLeave", THIS_CLASS);
            }
        }

        /// <summary>
        /// This method is used to populate teh dropdowns in the Main Grid.
        /// </summary>
       /// <param name="gridControl">NGSyncfusionGrid</param>
        private void ConfigureResultsDropDowns(NGSyncfusionGrid gridControl)
        {
            try
            {
                CADLog.LogDebug("Start of Method","ConfigureResultsDropDowns", THIS_CLASS);
                GridCurrentCell cc = gridControl.CurrentCell;
                if(cc.ColIndex == 1)
                {
                    GridDropDownGridListControlCellRenderer cr = cc.Renderer as GridDropDownGridListControlCellRenderer;
                    if (cr == null)
                        return;
                    cr.ListControlPart.ValueMember = "Notification Type";
                    cr.ListControlPart.BeginUpdate();
                    cr.ListControlPart.AutoSizeColumns = true;
                    ((GridDropDownGridListControlPart) cr.ListControlPart).DropDownRows = PreferredDropDownRowNum;
                    cr.ListControlPart.Properties.DisplayHorzLines = true;
                    cr.ListControlPart.Properties.DisplayVertLines = false;
                    DataView dvType=ddcNotificationType.GetDataView();
                    dvType.Table.Columns[0].ColumnName="Notification Type";
                    cr.ListControlPart.DataSource = ddcNotificationType.GetDataView();
                    if(FormPainted)
                        cr.ListControlPart.Height=59;
                    cr.ListControlPart.EndUpdate();
                }
                CADLog.LogDebug("End of Method","ConfigureResultsDropDowns", THIS_CLASS);
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"ConfigureResultsDropDowns", THIS_CLASS);
            }
        }
        /// <summary>
        /// This method is used to populate the dropdowns in the Notifications Grid.
        /// </summary>
       /// <param name="gridControl">NGSyncfusionGrid</param>
        private void ConfigureNotificationDropDowns(NGSyncfusionGrid gridControl)
        {
            try
            {
                CADLog.LogDebug("Start of Method","ConfigureNotificationDropDowns", THIS_CLASS);
                GridCurrentCell cc = gridControl.CurrentCell;
                GridDropDownGridListControlCellRenderer cr = cc.Renderer as GridDropDownGridListControlCellRenderer;
                if (cr == null)
                    return;
                cr.ListControlPart.BeginUpdate();
                cr.ListControlPart.AutoSizeColumns = true;
                ((GridDropDownGridListControlPart) cr.ListControlPart).DropDownRows = PreferredDropDownRowNum;
                cr.ListControlPart.Properties.DisplayHorzLines = true;
                cr.ListControlPart.Properties.DisplayVertLines = false;
                cr.ListControlPart.Grid.Model.Cols.Hidden[1]=false;
				cr.ListControlPart.ValueMember = "Value";
				cr.ListControlPart.DisplayMember="Value";
				
                if(cc.ColIndex == 1)
                {
                    DataListValidator ddcResourceType = new DataListValidator("RESOURCE TYPE");
                    DataView dvType=ddcResourceType.GetDataView();
					dvType.Table.Columns[0].ColumnName="Value";
                    dvType.Table.Columns.RemoveAt(3);
                    dvType.Table.Columns.RemoveAt(2);
                    dvType.Table.Columns.RemoveAt(1);
                    cr.ListControlPart.DataSource = dvType;
					if(FormPainted)
						cr.ListControlPart.Height=120;
                }
                else if (cc.ColIndex == 2)
                {
                    this.listControl = cr.ListControlPart;
                    cr.ListControlPart.Grid.Model.Cols.Hidden[1] = true;
                    string resourceType = gridControl[gridControl.CurrentCell.RowIndex,1].Text;
                    NGPNotificationResourceValidator nrValidator= new NGPNotificationResourceValidator(resourceType,this.CadBaseObject.TypeName,this.txtCongrpid.Text);
                    DataView dvVal = nrValidator.GetDataView();
					dvVal.Table.Columns[0].ColumnName="Value";
					dvVal.Table.Columns[1].ColumnName="Resource ID";
					dvVal.Table.Columns[2].ColumnName="Type Name";
					dvVal.Table.Columns[3].ColumnName="Notification Number";
					dvVal.Table.Columns[4].ColumnName="DisplayName";
                    if (dvVal.Count == 0)
                        cr.ListControlPart.DataSource = null;
                    else
                        cr.ListControlPart.DataSource = dvVal;
                    cr.ListControlPart.SelectedValueChanged -= new EventHandler(ListControlPart_Validated);
                    cr.ListControlPart.SelectedValueChanged += new EventHandler(ListControlPart_Validated);
                }
                cr.ListControlPart.EndUpdate();
                CADLog.LogDebug("End of Event","ConfigureNotificationDropDowns", THIS_CLASS);
            }
            catch (Exception ex)
            {
                CADLog.LogError(ex.ToString(),"ConfigureNotificationDropDowns", THIS_CLASS);
            }
        }
        #endregion

        private void tabControlNGP_SelectedIndexChanged(object sender, System.EventArgs e)
        {
            switch (tabControlNGP.SelectedIndex)
            {
                case 0:
                {
                    this.gdbgResults.Focus();
                    if (this.gdbgResults.Binder.RecordCount > 0)
                    {
                        this.gdbgResults.SetFocusToCell(1,1);
                    }
                    else
                    {
                        this.gdbgResults.SetFocusToCell(0,0);
                    }
                    break;
                }
                case 1:
                {
                    this.grdGrpNotification.Focus();
                    if (this.grdGrpNotification.Binder.RecordCount > 0)
                    {
                        this.grdGrpNotification.SetFocusToCell(1,1);
                    }
                    else
                    {
                        this.grdGrpNotification.SetFocusToCell(0,0);
                    }
                    break;
                }
            }
        }

        private void ListControlPart_Validated(object sender, EventArgs e)
        {
            if (this.listControl.SelectedItem as DataRowView != null)
            {
                this.selectedRow = this.listControl.SelectedItem as DataRowView;
            }
        }
        /// <summary>
        /// 
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void dtToDate_Validating(object sender, CancelEventArgs e)
        {
            try
            {
                CADLog.LogDebug("Start of Event","dtToDate_Leave", THIS_CLASS);
                if (this.dtToDate.Checked)
                {
                    this.CadBaseObject.ToDate =
                        DateTime.Today.Date.AddTicks(dtToDate.Value.TimeOfDay.Ticks);
                }
                else
                {
                    this.CadBaseObject.ToDate = DateTime.MinValue;
                }
                CADLog.LogDebug("Start of Event","dtToDate_Leave", THIS_CLASS);
            }
            catch(Exception ex)
            {
                this.ShowError(dtToDate, ex);
                CADLog.LogError(ex.ToString(),"dtToDate_Leave", THIS_CLASS);
            }
            finally
            {
                ProcessLeave();
            }
        }

        private void dtFromDate_Validating(object sender, CancelEventArgs e)
        {
            try
             {
                CADLog.LogDebug("Start of Event","dtFromDate_Leave", THIS_CLASS);
                 if (this.dtFromDate.Checked)
                 {
                     this.CadBaseObject.FromDate=DateTime.Today.Date.AddTicks(dtFromDate.Value.TimeOfDay.Ticks);
                 }
                 else
                 {
                    this.CadBaseObject.FromDate = DateTime.MinValue;
                 }
                CADLog.LogDebug("End of Event","dtFromDate_Leave", THIS_CLASS);
            }
            catch(Exception ex)
            {
                this.ShowError(dtFromDate, ex);
                CADLog.LogError(ex.ToString(),"dtFromDate_Leave", THIS_CLASS);
            }
            finally
            {
                ProcessLeave();
            }
        }

        private void txtNumberNotification_Validating(object sender, System.ComponentModel.CancelEventArgs e)
        {
            try
            {
                if (this.txtNumberNotification.Text.Trim().Length > 0)
                {

                }

                CADLog.LogDebug("Start of Event","txtNumberNotification_Leave", THIS_CLASS);
                this.CadBaseObject.NumberExceeds=txtNumberNotification.Text;
                this.ClearError(txtNumberNotification);
                CADLog.LogDebug("Start of Event","txtNumberNotification_Leave", THIS_CLASS);
            }
            catch(Exception ex)
            {
                this.ShowError(txtNumberNotification, ex);
                CADLog.LogError(ex.ToString(),"txtNumberNotification_Leave", THIS_CLASS);
            }
            finally
            {
                ProcessLeave();
            }
        }

        private void txtNumberNotification_KeyPress(object sender, KeyPressEventArgs e)
        {
            switch (e.KeyChar)
            {
                case (char) Keys.D1:
                case (char) Keys.D2:
                case (char) Keys.D3:
                case (char) Keys.D4:
                case (char) Keys.D5:
                case (char) Keys.D6:
                case (char) Keys.D7:
                case (char) Keys.D8:
                case (char) Keys.D9:
                case (char) Keys.D0:
                case (char) Keys.Back:
                {
                    break;
                }
                default :
                {
                    e.Handled = true;
                    break;
                }
            }
        }
    }
}

